#
# spec file for package telegraf
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _config_dir %{_sysconfdir}/%{name}
Name:           telegraf
Version:        1.22.1
Release:        bp154.1.17
Summary:        The plugin-driven server agent for collecting & reporting metrics
License:        MIT
Group:          System/Monitoring
URL:            https://github.com/influxdata/telegraf
Source:         %{name}-%{version}.tar.xz
Source1:        vendor.tar.xz
Patch0:         harden_telegraf.service.patch
BuildRequires:  git-core
BuildRequires:  golang-packaging
BuildRequires:  systemd-rpm-macros
BuildRequires:  golang(API) >= 1.17
%{?systemd_ordering}

%description
Telegraf is an agent written in Go for collecting, processing, aggregating, and writing metrics.

Design goals are to have a minimal memory footprint with a plugin system so that developers in the community can
easily add support for collecting metrics from local or remote services.

%prep
%setup -q
%setup -q -T -D -a 1
%patch0 -p1

%build
# Build the binary.
go build \
   -mod=vendor \
%ifnarch ppc64 ppc64le
   -buildmode=pie \
%endif
   ./cmd/telegraf;

%install
# Install the binary.
install -D -m 0755 %{name} "%{buildroot}/%{_bindir}/%{name}"

mkdir -p %{buildroot}/%{_config_dir}
mkdir -p %{buildroot}/%{_config_dir}/%{name}.d
install -m644 etc/%{name}.conf %{buildroot}/%{_config_dir}

install -D -m 644 scripts/%{name}.service %{buildroot}%{_unitdir}/%{name}.service
sed -i '/User=/d' %{buildroot}%{_unitdir}/%{name}.service
mkdir -p %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}

%pre
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%{_sbindir}/rc%{name}
%{_unitdir}/%{name}.service
%doc CHANGELOG.md CONTRIBUTING.md README.md
%license LICENSE
%dir %{_config_dir}
%config(noreplace) %{_config_dir}/%{name}.conf
%{_bindir}/%{name}

%changelog
* Mon Apr 25 2022 Jeff Kowalczyk <jkowalczyk@suse.com>
- Refresh harden_telegraf.service.patch
* Mon Apr 25 2022 jkowalczyk@suse.com
- Update to version 1.22.1:
  * fix: bump gonum.org/v1/gonum from 0.9.3 to 0.11.0 (#10937)
  * fix: bump github.com/golang-jwt/jwt/v4 from 4.2.0 to 4.4.1 (#10906)
  * chore: add actions/setup-go@v2 to linter config (#10935)
  * docs(external.psi): add psi plugin (#10462)
  * fix: Update gopsutil and associated dependencies for improved OpenBSD supp… (#10931)
  * docs: update rpm/deb instructions with stable URLs (#10905)
  * fix: inconsistencies in sql*Requests queries (#10553)
  * fix: default value for logfile rotation interval (#10883)
  * fix: redundant zfs pool tag (#10871)
  * docs: update license of dependencies (#10914)
  * fix: update vsphere info message to debug (#10903)
  * docs: fix contribute button link (#10904)
  * docs: improve documentation around contribution (#10825)
  * chore: set telegraf log as text block in bug reports (#10895)
  * fix: include body in error message (#10866)
  * docs: clarify the k and fields topk params (#10830)
  * chore: remove slow process test (#10856)
  * chore: update slow file rotation tests (#10857)
  * chore: switch HTTP 100 test case values (#10858)
  * chore: fix slow running intel-pmu test (#10859)
  * chore: skip longer/integration tests on -short mode (#10860)
  * chore: remove CircleCI parallelism (#10862)
  * chore: reduce timeouts and sleeps (#10861)
* Mon Apr 25 2022 jkowalczyk@suse.com
- Update to version 1.22.0:
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10843)
  * fix: fix handling of imports in protocol-buffer definitions (#10798)
  * fix: change name of snmp translator setting (#10872)
  * fix: rename consul_metrics -> consul_agent (#10876)
  * fix: consul_metrics input plugin docs (#10873)
  * tests: remove redundant newlines that go 1.18 treats as errors (#10847)
  * fix: Add option to select translator (#10802)
  * feat: new input Hugepages plugin (#10763)
  * fix: update the precision parameter default value (#10814)
  * fix: bump github.com/nats-io/nats-server/v2 from 2.7.3 to 2.7.4 (#10807)
  * feat: add new rtt per op field to nfsclient (#10787)
  * fix(parsers.json_v2): Check if gpath exists and support optional in fields/tags (#10799)
  * fix(inputs.snmp):  use the correct path when evaluating symlink (#10748)
  * fix: bump github.com/Shopify/sarama from 1.29.1 to 1.32.0 (#10772)
  * fix: update parsing logic of config.Duration (#10803)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10805)
  * feat(parsers.influx): New influx line protocol via feature flag (#10749)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10804)
  * docs: Improve language related to the New Relic license key. (#10796)
  * fix: correctly read ntpq long poll output (#10790)
  * fix(inputs.docker): keep field type of tasks_desired the same (#10711)
  * fix(json_v2): allow multiple optional objects (#10777)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10789)
  * docs: update wavefront docs for clearer proxy server use (#10774)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10779)
  * feat: HTTP basic auth for webhooks (#9332)
  * docs: update uri scheme for default RavenDB configuration (#10764)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10769)
  * fix: sql unsigned settings (#10673)
  * docs: better specify agent precision is integer + unit (#10746)
  * fix: bump github.com/shirou/gopsutil/v3 from 3.21.12 to 3.22.2 (#10758)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10760)
  * style: Add deprecation notices to plugin options (#10616)
  * fix: sanitize stasd names (#10466)
  * fix: bump github.com/aws/aws-sdk-go-v2/feature/ec2/imds (#10759)
  * fix: bump github.com/miekg/dns from 1.1.43 to 1.1.46 (#10757)
  * fix: bump github.com/aws/aws-sdk-go-v2/service/dynamodb (#10751)
  * fix: bump github.com/nats-io/nats-server/v2 from 2.7.2 to 2.7.3 (#10752)
  * docs: add value_field_name to value processor (#10740)
  * fix: log err when loading mibs (#10735)
  * docs: add info on Graylog GELF spec (#10745)
  * fix: typo metadata support in csv parser (#10742)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10737)
  * feat: Add tag batch-processing to XPath parser (#10585)
  * fix: add push only updated values flag to histogram aggregator (#10515)
  * feat(parsers/csv): Add metadata support to CSV parser plugin (#10083)
  * fix: Revert "fix: error msg for missing env variables in config (#10681)" (#10727)
  * fix: bump github.com/aws/aws-sdk-go-v2/config from 1.8.3 to 1.13.1 (#10720)
  * fix: bump github.com/testcontainers/testcontainers-go (#10728)
  * fix: bump github.com/aws/aws-sdk-go-v2/service/cloudwatchlogs (#10719)
  * fix: bump github.com/aws/aws-sdk-go-v2/feature/ec2/imds (#10721)
  * fix: bump github.com/wavefronthq/wavefront-sdk-go from 0.9.9 to 0.9.10 (#10718)
  * fix: bump github.com/ClickHouse/clickhouse-go from 1.5.1 to 1.5.4 (#10717)
  * fix: Linter fixes for config/config.go (#10710)
  * fix: bump k8s.io/api from 0.23.3 to 0.23.4 (#10713)
  * fix: bump cloud.google.com/go/pubsub from 1.17.1 to 1.18.0 (#10714)
  * fix: bump github.com/newrelic/newrelic-telemetry-sdk-go (#10715)
  * fix: mdstat when sync is less than 10%% (#10701)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10708)
  * fix: Remove verbose logging from disk input plugin (#10527)
  * feat: Bump github.com/aerospike/aerospike-client-go from 1.27.0 to 5.7.0 (#10604)
  * feat(inputs/memcached): Support client TLS origination to memcached (#10642)
  * feat: socks5 proxy support for websocket (#10672)
  * fix: error msg for missing env variables in config (#10681)
  * fix: include influxdb bucket name in error messages (#10706)
  * fix: openweathermap add feels_like field (#10705)
  * fix: Set NextCheckTime to LastCheckTime to avoid GroundWork to invent a value (#10623)
  * fix: bump github.com/aws/aws-sdk-go-v2/service/dynamodb from 1.5.0 to 1.13.0 (#10692)
  * fix: bump github.com/sensu/sensu-go/api/core/v2 from 2.12.0 to 2.13.0 (#10704)
  * fix: bump github.com/gophercloud/gophercloud from 0.16.0 to 0.24.0 (#10693)
  * fix: bump github.com/jackc/pgx/v4 from 4.14.1 to 4.15.0 (#10702)
  * fix(dedup): Modifying slice while iterating is dangerous (#10684)
  * fix: linter fixes for "import-shadowing: The name '...' shadows an import name" (#10689)
  * fix: bump github.com/aws/aws-sdk-go-v2/service/sts from 1.7.2 to 1.14.0 (#10602)
  * fix: update gosmi from v0.4.3 to v0.4.4 (#10686)
  * feat: update configs (#10676)
  * feat[elastic output]: add elastic pipeline flags (#10505)
  * fix: ensure folders do not get loaded more than once (#10551)
  * docs: update VMWare doc links (#10663)
  * fix: prometheusremotewrite wrong timestamp unit (#10547)
  * feat: update configs (#10662)
  * fix: add graylog toml tags (#10660)
  * feat: add socks5 proxy support for kafka output plugin (#8192)
  * docs: override reported OpenSearch version (#10586)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10659)
  * fix: bump all go.opentelemetry.io dependencies (#10647)
  * feat: collection offset implementation (#10545)
  * chore: update go to 1.17.7 (#10658)
  * fix: check for nil client before closing in amqp (#10635)
  * fix: timestamp change during execution of json_v2 parser. (#10657)
  * fix: bump github.com/signalfx/golib/v3 from 3.3.38 to 3.3.43 (#10652)
  * fix: bump github.com/aliyun/alibaba-cloud-sdk-go (#10653)
  * fix: incorrect handling of json_v2 timestamp_path (#10618)
  * feat: gather additional stats from memcached (#10641)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10649)
  * fix: Revert deprecation of http_listener_v2 (#10648)
  * fix: bump github.com/denisenkom/go-mssqldb from 0.10.0 to 0.12.0 (#10503)
  * fix: bump github.com/gopcua/opcua from 0.2.3 to 0.3.1 (#10626)
  * fix: use current time as ecs timestamp (#10636)
  * fix: bump github.com/nats-io/nats-server/v2 from 2.6.5 to 2.7.2 (#10638)
  * chore: add -race flag to go tests (#10629)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10631)
  * fix: license doc outdated causing CI failure (#10630)
  * fix: bump k8s.io/client-go from 0.22.2 to 0.23.3 (#10589)
  * feat: Implemented support for reading raw values, added tests and doc (#6501)
  * fix: Improve parser tests by using go-cmp/cmp (#10497)
  * feat(mongodb): add FsTotalSize and FsUsedSize informations (#10625)
  * docs: update quay docs for auth (#10612)
  * chore: allow downgrade of go version in windows script (#10614)
  * chore: update CI go to 1.17.6 (#10611)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10600)
  * fix(inputs.opcua): add more data to error log (#10465)
  * fix: bump github.com/aws/aws-sdk-go-v2/service/kinesis from 1.6.0 to 1.13.0 (#10601)
  * refactor: use early return pattern (#10591)
  * fix: bump github.com/benbjohnson/clock from 1.1.0 to 1.3.0 (#10588)
  * feat: add dynamic tagging to gnmi plugin (#7484)
  * fix: bump github.com/Azure/azure-kusto-go from 0.5.0 to 0.5.2 (#10598)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10584)
  * fix(parsers.json_v2): allow optional paths and handle wrong paths correctly (#10468)
  * docs: add expriation_interval to readme (#10583)
  * feat: aggregator histogram add expiration (#10520)
  * fix[elasticsearch output]: add scheme to fix error in sniffing option (#10513)
  * chore: fix typo in bug report template (#10582)
  * style: Add deprecated warning and version to win_perf_counters option (#10579)
  * feat: Add autorestart and restartdelay flags to Windows service (#10559)
  * fix: Statefull parser handling (#10575)
  * fix: bump github.com/vmware/govmomi from 0.27.2 to 0.27.3 (#10571)
  * fix: bump github.com/prometheus/client_golang from 1.11.0 to 1.12.1 (#10572)
  * fix: remove signed macOS dotfile artifacts (#10560)
  * fix: bump go.mongodb.org/mongo-driver from 1.7.3 to 1.8.3 (#10564)
  * fix: bump github.com/google/go-cmp from 0.5.6 to 0.5.7 (#10563)
  * fix: bump go.opentelemetry.io/collector/model from 0.39.0 to 0.43.2 (#10562)
  * fix: bump github.com/multiplay/go-ts3 from 1.0.0 to 1.0.1 (#10538)
  * fix: bump cloud.google.com/go/monitoring from 0.2.0 to 1.2.0 (#10454)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10561)
  * docs: updates readme to add service SID auth and cleans up AAD auth dupe info (#10541)
  * feat: Add caching to internet_speed (#10530)
  * feat: Xtremio input (#9697)
  * feat(inputs.win_perf_counter): allow errors to be ignored (#10535)
  * fix(outputs/azure_data_explorer): Added azureBlob controls to lower RAM usage (#10179)
  * fix: bump github.com/vmware/govmomi from 0.26.0 to 0.27.2 (#10536)
  * docs: add apt and knot to EXTERNAL_PLUGINS.md (#10552)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10546)
  * fix: move "Starting Telegraf" log (#10528)
  * fix: update docker memory usage calculation (#10491)
  * feat: Add ClickHouse driver to sql inputs/outputs plugins (#9671)
  * fix: collapsed fields by calling more indepth function (#10430)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10533)
  * feat: process group tag for groundwork output plugin (#10499)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10532)
  * docs: Update deprecation readme (#10529)
  * feat: add FileVersion and icon to Win exe (#10487)
  * chore: update grpc to v1.44.0 (#10525)
  * fix: bump google.golang.org/api from 0.54.0 to 0.65.0 (#10434)
  * fix: typo in docs (#10441)
  * fix: bump github.com/antchfx/xmlquery from 1.3.6 to 1.3.9 (#10507)
  * fix: bump github.com/nsqio/go-nsq from 1.0.8 to 1.1.0 (#10521)
  * fix: bump github.com/prometheus/common from 0.31.1 to 0.32.1 (#10506)
  * fix: ipset crash when command not found (#10474)
  * fix: bump cloud.google.com/go/pubsub from 1.17.0 to 1.17.1 (#10504)
  * fix: bump github.com/influxdata/influxdb-observability/influx2otel from 0.2.8 to 0.2.10 (#10432)
  * fix: Update modbus readme (#10501)
  * Fix: Update README.md (#10500)
  * docs: Fixes for input/sql readme (#10498)
  * feat: update configs (#10490)
  * fix: graylog readme to use graylog 3 URLs (#10481)
  * fix: add RFC3164 to RFC5424 translation to docs (#10480)
  * fix: add comment to logparser (#10479)
  * chore: Add `openConnections` to enterprise cluster metrics Readme (#10483)
  * fix: remove duplicate addition of fields (#10478)
  * fix(parsers.nagios): nagios parser now uses real error for logging #10472 (#10473)
  * fix: add newline in execd for prometheus parsing (#10463)
  * fix: bump github.com/shirou/gopsutil/v3 from 3.21.10 to 3.21.12 (#10451)
  * fix: do not save cache on i386 builds (#10464)
  * chore: readme escape rpm variables
  * fix: address flaky tests in cookie_test.go and graylog_test.go (#10326)
  * feat: check TLSConfig early to catch missing certificates (#10341)
  * fix: ensure CI tests runs against i386 (#10457)
  * fix: bump github.com/jackc/pgx/v4 from 4.6.0 to 4.14.1 (#10453)
  * fix: bump github.com/Azure/azure-event-hubs-go/v3 from 3.3.13 to 3.3.17 (#10449)
  * fix: bump github.com/gosnmp/gosnmp from 1.33.0 to 1.34.0 (#10450)
  * fix: wavefront_disable_prefix_conversion case missing from missingTomlField func (#10442)
  * fix: bump github.com/hashicorp/consul/api from 1.9.1 to 1.12.0 (#10435)
  * feat: Parser plugin restructuring (#8791)
  * fix: bump github.com/antchfx/jsonquery from 1.1.4 to 1.1.5 (#10433)
  * fix: bump github.com/prometheus/procfs from 0.6.0 to 0.7.3 (#10414)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10429)
  * feat: Add noise plugin (#10057)
  * feat: update configs (#10425)
  * fix: Accept non-standard OPC UA OK status by implementing a configurable workaround (#10384)
  * feat: support headers for http plugin with cookie auth (#10404)
  * fix: snmp input plugin errors if mibs folder doesn't exist (#10346) (#10354)
  * fix: correctly set ASCII trailer for syslog output (#10393)
  * feat: update configs (#10424)
  * chore: go mod tidy (#10423)
  * fix: bump github.com/aws/aws-sdk-go-v2/service/cloudwatchlogs from 1.5.2 to 1.12.0 (#10415)
  * fix: bump github.com/kardianos/service from 1.0.0 to 1.2.1 (#10416)
  * fix: ensure http body is empty (#10396)
  * feat: add bearer token support to elasticsearch output (#10399)
  * fix: bump github.com/couchbase/go-couchbase from 0.1.0 to 0.1.1 (#10417)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10411)
  * fix(json_v2): use raw values for timestamps (#10413)
  * fix: bump github.com/pion/dtls/v2 from 2.0.9 to 2.0.13 (#10418)
  * chore: update mqtt documentation (#10394)
  * feat: deprecate unused snmp_trap timeout configuration option (#10339)
  * fix: update containerd to 1.5.9 (#10402)
  * feat: update configs (#10400)
  * feat:  add compression to Datadog Output (#9963)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10395)
  * fix: re-enable OpenBSD modbus support (#10385)
  * fix: Fix batching logic with write records, introduce concurrent requests (#8947)
  * feat: Add additional stats to bond collector (#10137)
  * fix(outputs/amqp): Close the last connection when writing error to avoid connection leaks (#10360)
  * feat: update docker client API version (#10382)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10381)
  * fix: fix missing storage in container with disk plugin (#10318)
  * feat: add systemd notify support (#10340)
  * chore: typos across source code comments (#10361)
  * chore: sql readme with more details on data types (#10378)
  * fix: empty import tzdata for Windows binaries (#10377)
  * feat: update configs (#10374)
  * chore: document deprecation of timeout (#10373)
  * feat: update configs (#10345)
  * feat: add mock input plugin (#9782)
  * chore: use 4 cores on linux systems (#10342)
  * fix: update go-ldap to v3.4.1 (#10343)
  * chore: remove "i386" test job (#10344)
  * fix: update GroundWork SDK and improve logging (#10255)
  * feat: add more functionality to template processor (#10316)
  * chore: run release signing jobs at the same time (#10333)
  * feat: update configs (#10336)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10335)
  * feat: add builds for riscv64 (#10262)
  * feat: add consul metrics input plugin (#10258)
  * fix: snmp marshal error (#10322)
  * feat: add exclude_root_certs option to x509_cert plugin (#9822)
  * feat: add option to disable prepared statements for PostgreSQL (#9710)
  * fix: cumulative interval start times for stackdriver output (#10097)
  * feat: add option to skip errors during CSV parsing (#10267)
  * feat: update configs (#10334)
  * feat: socketstat input plugin (#3649)
  * fix: update djherbis/times and fix dependabot (#10332)
  * fix: warning output when running with --test (#10329)
  * feat: update configs (#10325)
  * docs: add note about dpdk and socket availability (#10324)
  * feat: reworked varnish_cache plugin (#9432)
  * chore:  release packaging run in parallel (#10314)
  * fix: update bug template
  * chore: add logs section for bug reports (#10323)
  * fix: do not require networking during tests (#10321)
  * chore: update mac signing job to use latest xcode (#10311)
  * chore: update Go version to 1.17.5 (#10310)
  * feat: update configs (#10319)
  * chore: cleanup go.mod (#10313)
  * feat: add timeout-setting to Graylog-plugin (#10220)
  * feat: Improve error logging on plugin initialization (#10307)
  * fix: Fix panic in logparser due to missing Log. (#10296)
  * fix: panic due to no module (#10303)
  * fix: grab table columns more accurately (#10295)
  * fix: check index before assignment (#10299)
  * feat: adds optional list of non retryable http statuscodes to http output plugin (#10186)
  * fix: panic is no mibs folder is found (#10301)
  * fix: mac signing issue with arm64 (#10293)
  * fix: Update go-sensu to v2.12.0 (#10247)
  * fix: typo in openstack neutron input plugin (newtron) (#10284)
  * fix: Fix panic in parsers due to missing Log for all plugins using SetParserFunc. (#10288)
  * fix: mark TestGatherUDPCert as an integration test (#10279)
  * feat: support darwin arm64 (#10239)
  * feat: update configs (#10275)
  * fix: run gofmt (#10274)
  * fix: run go mod tidy (#10273)
  * fix: inputs.snmp to respect number of retries configured (#10268)
  * feat: add Redis Sentinel input plugin (#10042)
  * fix: flush wavefront output sender on error to clean up broken connections (#10225)
  * feat: Add option to disable Wavefront prefix conversion (#10252)
  * feat: add heap_size_limit field for input.kibana (#10243)
  * fix: use sha256 for RPM digest (#10272)
  * feat: Update underlying KNX library to support new types. (#10263)
  * chore: restart service if it is already running and upgraded via RPM (#9970)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10237)
  * fix: Handle duplicate registration of protocol-buffer files gracefully. (#10188)
  * fix(http_listener_v2): fix panic on close (#10132)
  * feat: add Vault input plugin (#10198)
  * feat: support aws managed service for prometheus (#10202)
  * fix: Make telegraf compile on Windows with golang 1.16.2 (#10246)
  * feat: Modbus add per-request tags (#10231)
  * fix: Implement NaN and inf handling for elasticsearch output (#10196)
  * feat: add nomad input plugin (#10106)
  * fix: Print loaded plugins and deprecations for once and test (#10205)
  * fix: eliminate MIB dependency for ifname processor (#10214)
  * feat: Optimize locking for SNMP MIBs loading. (#10206)
  * feat: Add SMART plugin concurrency configuration option, nvme-cli v1.14+ support and lint fixes. (#10150)
  * feat: update configs (#10236)
  * fix(inputs/kube_inventory): set TLS server name config properly (#9975)
  * fix: Sudden close of Telegraf caused by OPC UA input plugin (#10230)
  * fix: bump github.com/eclipse/paho.mqtt.golang from 1.3.0 to 1.3.5 (#9913)
  * fix: json_v2 parser timestamp setting (#10221)
  * fix: ensure graylog spec fields not prefixed with '_' (#10209)
  * docs: remove duplicate links in CONTRIBUTING.md (#10218)
  * fix: pool detection and metrics gathering for ZFS >= 2.1.x (#10099)
  * fix: parallelism fix for ifname processor (#10007)
  * chore: Forbids "log" package only for aggregators, inputs, outputs, parsers and processors (#10191)
  * docs: address documentation gap when running telegraf in k8s (#10215)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10211)
  * fix: mqtt topic extracting no longer requires all three fields (#10208)
  * fix: windows service - graceful shutdown of telegraf (#9616)
  * feat: update etc/telegraf.conf and etc/telegraf_windows.conf (#10201)
  * feat: Modbus support multiple slaves (gateway feature) (#9279)
  * fix: Revert unintented corruption of the Makefile from #10200. (#10203)
  * chore: remove triggering update-config bot in CI (#10195)
* Mon Apr 25 2022 jkowalczyk@suse.com
- Update to version 1.21.4:
  * fix: ensure folders do not get loaded more than once (#10551)
  * docs: update VMWare doc links (#10663)
  * fix: prometheusremotewrite wrong timestamp unit (#10547)
  * docs: override reported OpenSearch version (#10586)
  * fix: bump all go.opentelemetry.io dependencies (#10647)
  * chore: update go to 1.17.7 (#10658)
  * fix: check for nil client before closing in amqp (#10635)
  * fix: timestamp change during execution of json_v2 parser. (#10657)
  * fix: bump github.com/signalfx/golib/v3 from 3.3.38 to 3.3.43 (#10652)
  * fix: bump github.com/aliyun/alibaba-cloud-sdk-go (#10653)
  * fix: incorrect handling of json_v2 timestamp_path (#10618)
  * fix: Revert deprecation of http_listener_v2 (#10648)
  * fix: bump github.com/denisenkom/go-mssqldb from 0.10.0 to 0.12.0 (#10503)
  * fix: bump github.com/gopcua/opcua from 0.2.3 to 0.3.1 (#10626)
  * fix: update go.mod
  * fix: use current time as ecs timestamp (#10636)
  * fix(outputs/azure_data_explorer): Added azureBlob controls to lower RAM usage (#10179)
  * fix: bump github.com/nats-io/nats-server/v2 from 2.6.5 to 2.7.2 (#10638)
  * chore: add -race flag to go tests (#10629)
  * fix: license doc outdated causing CI failure (#10630)
  * fix: bump k8s.io/client-go from 0.22.2 to 0.23.3 (#10589)
  * docs: update quay docs for auth (#10612)
  * chore: allow downgrade of go version in windows script (#10614)
  * chore: update CI go to 1.17.6 (#10611)
  * fix: bump github.com/aws/aws-sdk-go-v2/service/kinesis from 1.6.0 to 1.13.0 (#10601)
  * refactor: use early return pattern (#10591)
  * fix: bump github.com/benbjohnson/clock from 1.1.0 to 1.3.0 (#10588)
  * fix: bump github.com/Azure/azure-kusto-go from 0.5.0 to 0.5.2 (#10598)
  * fix(parsers.json_v2): allow optional paths and handle wrong paths correctly (#10468)
  * fix[elasticsearch output]: add scheme to fix error in sniffing option (#10513)
  * chore: fix typo in bug report template (#10582)
  * style: Add deprecated warning and version to win_perf_counters option (#10579)
  * fix: bump github.com/vmware/govmomi from 0.27.2 to 0.27.3 (#10571)
  * fix: bump github.com/prometheus/client_golang from 1.11.0 to 1.12.1 (#10572)
  * fix: remove signed macOS dotfile artifacts (#10560)
  * fix: bump go.mongodb.org/mongo-driver from 1.7.3 to 1.8.3 (#10564)
  * fix: bump github.com/google/go-cmp from 0.5.6 to 0.5.7 (#10563)
  * fix: bump go.opentelemetry.io/collector/model from 0.39.0 to 0.43.2 (#10562)
  * fix: bump github.com/multiplay/go-ts3 from 1.0.0 to 1.0.1 (#10538)
  * fix: bump cloud.google.com/go/monitoring from 0.2.0 to 1.2.0 (#10454)
  * fix: bump github.com/vmware/govmomi from 0.26.0 to 0.27.2 (#10536)
  * docs: add apt and knot to EXTERNAL_PLUGINS.md (#10552)
  * fix: update docker memory usage calculation (#10491)
* Mon Apr 25 2022 jkowalczyk@suse.com
- Update to version 1.21.3:
  * Update license of dependencies file
  * fix: collapsed fields by calling more indepth function (#10430)
  * docs: Update deprecation readme (#10529)
  * chore: update grpc to v1.44.0 (#10525)
  * fix: bump google.golang.org/api from 0.54.0 to 0.65.0 (#10434)
  * fix: typo in docs (#10441)
  * fix: bump github.com/antchfx/xmlquery from 1.3.6 to 1.3.9 (#10507)
  * fix: bump github.com/nsqio/go-nsq from 1.0.8 to 1.1.0 (#10521)
  * fix: bump github.com/prometheus/common from 0.31.1 to 0.32.1 (#10506)
  * fix: ipset crash when command not found (#10474)
  * fix: bump cloud.google.com/go/pubsub from 1.17.0 to 1.17.1 (#10504)
  * fix: bump github.com/influxdata/influxdb-observability/influx2otel from 0.2.8 to 0.2.10 (#10432)
  * fix: Update modbus readme (#10501)
  * Fix: Update README.md (#10500)
  * docs: Fixes for input/sql readme (#10498)
  * fix: graylog readme to use graylog 3 URLs (#10481)
  * fix: add RFC3164 to RFC5424 translation to docs (#10480)
  * fix: add comment to logparser (#10479)
  * chore: Add `openConnections` to enterprise cluster metrics Readme (#10483)
  * fix: remove duplicate addition of fields (#10478)
  * fix(parsers.nagios): nagios parser now uses real error for logging #10472 (#10473)
  * fix: add newline in execd for prometheus parsing (#10463)
  * fix: bump github.com/shirou/gopsutil/v3 from 3.21.10 to 3.21.12 (#10451)
  * fix: do not save cache on i386 builds (#10464)
  * chore: readme escape rpm variables
  * fix: address flaky tests in cookie_test.go and graylog_test.go (#10326)
  * fix: ensure CI tests runs against i386 (#10457)
  * fix: bump github.com/jackc/pgx/v4 from 4.6.0 to 4.14.1 (#10453)
  * fix: bump github.com/Azure/azure-event-hubs-go/v3 from 3.3.13 to 3.3.17 (#10449)
  * fix: bump github.com/gosnmp/gosnmp from 1.33.0 to 1.34.0 (#10450)
  * fix: wavefront_disable_prefix_conversion case missing from missingTomlField func (#10442)
  * fix: bump github.com/hashicorp/consul/api from 1.9.1 to 1.12.0 (#10435)
  * fix: bump github.com/antchfx/jsonquery from 1.1.4 to 1.1.5 (#10433)
  * fix: bump github.com/prometheus/procfs from 0.6.0 to 0.7.3 (#10414)
  * fix: snmp input plugin errors if mibs folder doesn't exist (#10346) (#10354)
  * fix: correctly set ASCII trailer for syslog output (#10393)
  * chore: go mod tidy (#10423)
  * fix: bump github.com/aws/aws-sdk-go-v2/service/cloudwatchlogs from 1.5.2 to 1.12.0 (#10415)
  * fix: bump github.com/kardianos/service from 1.0.0 to 1.2.1 (#10416)
  * fix: ensure http body is empty (#10396)
  * fix: bump github.com/couchbase/go-couchbase from 0.1.0 to 0.1.1 (#10417)
  * fix(json_v2): use raw values for timestamps (#10413)
  * fix: bump github.com/pion/dtls/v2 from 2.0.9 to 2.0.13 (#10418)
  * chore: update mqtt documentation (#10394)
  * fix: update containerd to 1.5.9 (#10402)
  * fix: Fix batching logic with write records, introduce concurrent requests (#8947)
  * fix(outputs/amqp): Close the last connection when writing error to avoid connection leaks (#10360)
  * fix: cumulative interval start times for stackdriver output (#10097)
  * fix: Make telegraf compile on Windows with golang 1.16.2 (#10246)
* Fri Jan 21 2022 Felix Niederwanger <felix.niederwanger@suse.com>
- Build-requirement increased to go > 1.17
* Wed Jan 12 2022 reichwald@b1-systems.de
- Update to version 1.21.2:
  * Add json_timestamp_layout configuration option
  * output.http add use_batch_format configuration option
  * Many bug fixes, see full list:
  https://github.com/influxdata/telegraf/releases/tag/v1.21.2
- Update to version 1.21.1:
  * inputs.smart Add SMART plugin concurrency configuration option, nvme-cli v1.14+ support
  * Some bug fixes, see full list:
  https://github.com/influxdata/telegraf/releases/tag/v1.21.1
- Update to version 1.21.0:
  * New Input Plugins
  * intel_pmu input plugin
  * Linux Volume Manager input plugin
  * Openstack input plugin
  * New Output Plugins
  * groundwork output plugin
  * mongodp output plugin
  * Azure Event Hubs output plugin
  * Many bug fixes, see full list:
  https://github.com/influxdata/telegraf/releases/tag/v1.21.0
* Tue Dec 14 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.20.4:
  * Update go version to 1.17.3
  * Update deprecated plugin READMEs to better indicate deprecation
  * Update dependencies
  * inputs.mongodb Update readme with correct connection URI
  * inputs.mysql Fix type conversion follow-up
  * inputs.proxmox Changed VM ID from string to int
  * inputs.modbus Do not build modbus on openbsd
  * inputs.cisco_telemetry_mdt Move to new protobuf library
  * outputs.loki Add metric name with label "__name"
  * inputs.nvidia_smi Set the default path correctly
  * inputs.sqlserver Add elastic pool in supported versions
    in sqlserver
  * inputs.influxdb Update influxdb input schema docs
  * inputs.intel_rdt Correct timezone handling
* Fri Nov 26 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.20.3:
  * New External Plugins
  * IBM DB2
  * Oracle Database
  * Many bug fixes, see full list:
  https://github.com/influxdata/telegraf/releases/tag/v1.20.3
- Update to version 1.20.2:
  * parsers.influx Fix memory leak in influx parser
  * Minor other bug fixes
* Thu Nov 25 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.20.1:
  * inputs.elasticsearch_query Add custom time/date format field
  * Some bug fixes, see list:
  https://github.com/influxdata/telegraf/releases/tag/v1.20.1
- Update to version 1.20.0:
  * New Input Plugins
  * Add rocm_smi input to monitor AMD GPUs
  * Add mdstat input to gather from /proc/mdstat collection
  * Add Elasticsearch query input
  * Add internet Speed Monitor Input Plugin
  * New Output Plugins
  * Add OpenTelemetry output
  * Add Azure Data Explorer(ADX) output
  * Features:
  * inputs.systemd_units feat(plugins/inputs/systemd_units): add
    pattern support
  * inputs.cloudwatch Pull metrics from multiple AWS CloudWatch
    namespaces
  * inputs.cloudwatch Support AWS Web Identity Provider
  * inputs.modbus Add support for RTU over TCP
  * Many other bug fixes and features, full list:
    https://github.com/influxdata/telegraf/releases/tag/v1.20.0
* Wed Nov 24 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_telegraf.service.patch
* Thu Jul  1 2021 rpm@fthiessen.de
- Update to version 1.19.0:
  * Update Go to 1.16.5
  * Many linter fixes
  * New Input Plugins
  * Alibaba CloudMonitor Service (Aliyun)
  * OpenTelemetry
  * Intel Data Plane Development Kit (DPDK)
  * KNX, SQL
  * New Output Plugins: Websocket, SQL, AWS Cloudwatch logs
  * New Parser Plugins: Prometheus Remote Write, JSON V2
  * Bugfixes
  * Fix reading config files starting with http
  * serializers.prometheusremotewrite Update dependency and remove
    tags with empty values
  * outputs.kafka Don't prevent telegraf from starting when
    there's a connection error
  * outputs.dynatrace Use dynatrace-metric-utils
  * parsers.json_v2 Update json_v2 parser to handle null types
  * inputs.sql Fix import of sqlite and ignore it on all platforms
    that require CGO.
  * inputs.kube_inventory Fix connecting to the wrong url
  * processors.parser Fix segfault
  * inputs.docker Close all idle connections
  * inputs.suricata Support new JSON format
  * outputs.influxdb Fix endless retries
  * Features
  * Add named timestamp formats
  * Allow multiple "--config" and "--config-directory" flags
  * Config file environment variable can be a URL
  * common.http Add OAuth2 to HTTP input
  * outputs.datadog Add HTTP proxy to datadog output
  * outputs.graphite Allow more characters in graphite tags
  * processors.strings Add UTF-8 sanitizer
  * processors.enum Support float64
  * processors.starlark Support nanosecond resolution timestamp
  * processors.starlark Add math module
  * processors.starlark Add an example showing how to obtain IOPS from
    diskio input
  * parsers.value Add custom field name config option
  * parsers.prometheusremotewrite Add starlark script for
    renaming metrics
  * inputs.vsphere Add config option for the historical interval
    duration
  * inputs.ping Add an option to specify packet size
  * inputs.sqlserver Added login_name
  * inputs.dovecot Add support for unix domain sockets
  * inputs.aliyuncms Add config option list of regions to query
  * inputs.sqlserver Enable Azure Active Directory (AAD)
    authentication support
  * inputs.cloudwatch Add wildcard support in dimensions configuration
  * inputs.mysql Gather all mysql channels
  * inputs.logstash Add support for version 7 queue stats
  * inputs.couchbase Add ~200 more Couchbase metrics via Buckets
    endpoint
  * inputs.sqlserver input/sqlserver: Add service and save connection pools
  * inputs.x509_cert Wildcard support for cert filenames
  * processors.starlark Add time module
  * inputs.kinesis_consumer Add content_encoding option with gzip
    and zlib support
  * inputs.sqlserver Add an optional health metric
  * inputs.http_listener_v2 Add support for snappy compression
  * inputs.cisco_telemetry_mdt Add support for events and class based query
  * inputs.mongodb Optionally collect top stats
* Tue May 18 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.18.2
  * processors.converter Add support for large hexadecimal strings
  * inputs.apcupsd Fix apcupsd 'ALARMDEL' bug via forked repo
  * parsers.json Make JSON format compatible with nulls
  * inputs.nfsclient Fix nfsclient ops map to allow collection of
    metrics other than read and write
  * inputs.snmp Log snmpv3 auth failures
  * common.shim Accept larger inputs from scanner
  * inputs.vsphere Add MetricLookback setting to handle reporting
    delays in vCenter 6.7 and later
  * outputs.sumologic Carbon2 serializer: sanitize metric name
  * inputs.opcua Fix error handling
* Wed Apr  7 2021 jkowalczyk@suse.com
- Update to version 1.18.1:
  * Add ability to handle 'binary logs' mySQL query with 3 columns, in case 3 columns are sent (MySQL 8 and greater) (#9082)
  * Add configurable option for the 'path' tag override in the Tail plugin. (#9069)
  * fix nfsclient merge to release-1.18 branch
  * inputs.nfsclient: use uint64, also update error handling (#9067)
  * Fix inputs.snmp init when no mibs installed (#9050)
  * inputs.ping: Always SetPrivileged(true) in native mode (#9072)
  * Don't walk the entire interface table to just retrieve one field (#9043)
  * readme fix (#9064)
  * use correct compute metadata url to get folder-id (#9056)
  * Handle error when initializing the auth object in Azure Monitor output plugin. (#9048)
  * update: inputs.sqlserver support version in readme (#9040)
  * SQLServer - Fixes sqlserver_process_cpu calculation (#8549)
  * Fix ipmi panic (#9035)
  * check for length of perusage for stat gathering and removed not used function (#9009)
  * update new plugins in changelog (#8991)
  * exec plugins should not truncate messages in debug mode (#8333)
  * Close running outputs when reloading (#8769)
* Wed Mar 17 2021 jkowalczyk@suse.com
- Update to version 1.18.0:
  * fix segfaults in sflow plugin by checking if protocol headers are set (#8995)
  * Teamspeak input plugin query clients (#8950)
  * Improve xml parser's handling of missing values (#8971)
  * chore: remove references to outdated InfluxDB settings. (#8754)
  * nats_output: use the configured credentials file (#8986)
  * Bigquery output Plugin (#8634)
  * feat: Adding Plex Webhooks external plugin (#8898)
  * accurate state documentation for Starlark
  * Filter data out from system databases for Azure SQL DB only (#8849)
  * Mac entry script: Add space before calling path so that zsh doesn't remove first character of path when prompting for update. (#8976)
  * Include DMG files when syncing release artifacts to AWS (#8972)
  * fix ping tests
  * add more logging to ping plugin
  * Writing unit tests for Kinesis output plugin Write method (#8930)
  * Fix output name to match directory name for sensu output plugin (#8960)
  * New plugins readme cleanup (#8956)
  * Reset the flush interval timer when flush is requested or batch is ready. (#8953)
  * Add Starlark parsing example of nested JSON (#8675)
  * NFS Client input plugin README cleanup (#8943)
  * Fix max open requests to one if idempotent writes is set to true (#8954)
  * Prometheus [Input] plugin - Optimizing for bigger kubernetes clusters (500+ pods) when scraping thru 'monitor_kubernetes_pods' (#8762)
  * Set $HOSTIP in default URL (#8721)
  * Correct Q+A about state (#8918)
  * Add field key length output by field type in schema_sizing Starlark script (#8934)
  * Mac Packaging / Notarization (#8878)
  * Nfsclient input: (Reopen of PR 1491 and 1684) (#4615)
  * chore: update docs link in influxdbv2listener (#8939)
  * fix: Beat readme title (#8938)
  * Get Tail tests to pass on windows (#8927)
  * chore: update csgo readme title (#8933)
  * Add XML parser using XPath queries (#8931)
  * Clearing LGTM alerts and warnings (#8923)
  * Input plugin for RavenDB (#8834)
  * Add Derivative Aggregator Plugin (#3762)
  * Add CSGO SRCDS input plugin (#8525)
  * [plugins/input/docker] Make perdevice affect also cpu and add class granularity through perdevice_include/total_include  (#7312)
  * Sensu Go Output Plugin for Telegraf (#8398)
  * Switching kinesis output plugin to use telegraf.Logger (#8929)
  * Add PPID field to procstat input plugin (#8887)
  * Adding a new directory monitor input plugin.  (#8751)
  * Add Starlark script for estimating Line Protocol cardinality (#8852)
  * Dynatrace Plugin: Make conversion to counters possible / Changed large bulk handling (#8397)
  * plugin: output loki (#8450)
  * SqlServer - fix for default server list (#8655)
  * Add MessagePack output data format (#8828)
  * Use consistent container name in docker input plugin (#8703)
  * Revive fixes - part 3 (#8872)
  * Fix max_repetitions signedness issues #8823 (#8902)
  * outputs.kinesis - log record error count (#8817)
  * Bug Fix - SQL Server HADR queries for SQL Versions (#8833)
  * add proxy (#8915)
  * Display error message on badly formatted config string array (eg. namepass) (#8910)
  * fix: reading multiple holding registers in modbus input plugin (#8628)
  * Non systemd support with unittest (#8785)
  * Fix statsd concurrency bug (#8885)
  * SignalFx Output (#6714)
  * Support more snmpv3 authentication protocols (#8850)
  * add SMCIPMITool input to external plugin list (#8897)
  * SQL Perfmon counters - synced queries from v2 to all db types (#8393)
  * Fix mutex locking around ifname cache  (#8873)
  * Run revive linter in CI (#8798)
  * Add quantile aggregator plugin (#8594)
  * plugins/filestat: Skip missing files (#7316)
  * added member_id as tag(as it is a unique value) for redfish plugin and added address of the server when the status is other than 200 for better debugging (#8813)
  * Revive fixes - part 2 (#8835)
  * Bump github.com/gopcua/opcua from 0.1.12 to 0.1.13 (#8744)
  * Support exclamation mark to create non-matching list in tail plugin (#8613)
  * Add support for datadog distributions metric (#8179)
  * outputs/warp10: url encode comma in tags value (#8657)
  * inputs.x509_cert: Fix timeout issue  (#8824)
  * update min Go version in Telegraf readme (#8846)
  * Add default retry for load config via url (#8803)
  * Code Signing for Windows (#8816)
  * Fix reconnection issues mqtt (#8821)
  * Validate the response from InfluxDB after writing/creating a database to avoid json parsing panics/errors (#8775)
  * Move windows tests to circle-ci, remove appveyor (#8844)
  * Expose v4/v6-only connection-schemes through GosnmpWrapper (#8804)
  * adds missing & to flush_jitter output ref (#8838)
  * Sort and timeout is deadline (#8839)
  * Revive fixes - part 1 (#8797)
  * Update README for inputs.ping with correct cmd for native ping on Linux (#8787)
  * Increase build verbosity with go mod download -x (#8496)
  * AWS EC2 metadata processor Using StreamingProcessor (#8707)
  * Update go-ping to latest version (#8771)
  * Allow to provide constants to a starlark script (#8772)
  * Add HTTP proxy setting to New Relic output plugin (#8749)
  * Set interface for native (#8770)
  * Resolve regression, re-add missing function (#8764)
  * [outputs.influxdb_v2] add exponential backoff, and respect client error responses (#8662)
  * add line about measurement being specified in docs (#8734)
  * Fix issue with elasticsearch output being really noisy about some errors (#8748)
  * Add geoip external project reference
  * improve mntr regex to match user specific keys. (#7533)
  * Fix crash in lustre2 input plugin, when field name and value (#7967)
  * Update grok-library to v1.0.1 with dots and dash-patterns fixed. (#8673)
  * Use go-ping for "native" execution in Ping plugin (#8679)
  * Integration test audit (#8725)
  * fix x509 cert timeout issue (#8741)
  * Add setting to enable caching in ipmitool (#8335)
  * Bump github.com/nsqio/go-nsq from 1.0.7 to 1.0.8 (#8714)
  * Bump github.com/Shopify/sarama from 1.27.1 to 1.27.2 (#8715)
  * fix: remove ambiguity on '\v' from line-protocol parser (#8720)
  * add kafka connect example to jolokia2 input (#8709)
  * Bump github.com/newrelic/newrelic-telemetry-sdk-go from 0.2.0 to 0.5.1 (#8712)
  * Create dependabot.yml (#8614)
  * Add Event Log support for Windows (#8616)
  * update readme: prometheus remote write (#8683)
  * Fix Redis output field type inconsistencies (#8678)
  * GNMI plugin should not take off the first character of field keys when no 'alias path' exists. (#8659)
  * Update template, remove CLA checkbox (#8680)
  * Use the 'measurement' json field from the particle webhook as the measurment name, or if it's blank, use the 'name' field of the event's json. (#8609)
  * Procstat input plugin should use the same timestamp in all metrics in the same Gather() cycle. (#8658)
  * update data formats output docs (#8674)
  * Add timestamp column support to postgresql_extensible (#8602)
  * Added ability to define skip values in csv parser (#8627)
  * Removing .lgtm.yml (#8664)
  * fix some annoying tests due to ports in use
  * Add Beat input plugin (#6653)
  * add todo note about wavefront dependencies
  * Optimize SeriesGrouper & aggregators.merge (#8391)
  * Using mime-type in prometheus parser to handle protocol-buffer responses (#8545)
  * Input SNMP plugin - upgrade gosnmp library to version 1.29.0 (#8588)
  * Provide test environment for kibana input plugin (#8629)
  * Upgrade circle-ci config to v2.1 (#8621)
  * remove redundant reference to docs in data formats docs (#8652)
  * alphabetize external plugins list (#8647)
  * Open Hardware Monitor (#8646)
  * outputs/http: add option to control idle connection timeout (#8055)
  * Lgtm config (#8625)
  * update influxdb_v2 config documentation in main (#8618)
  * update intel powerstat readme (#8600)
  * common/tls: Allow specifying SNI hostnames (#7897)
  * Fix spelling and clarify docs (#8164)
  * fixed formatting (+1 squashed commit) (#8541)
  * Provide method to include core count when reporting cpu_usage in procstat input (#6165)
  * Add support for an inclusive job list in Jenkins plugin (#8287)
  * improve the error log message for snmp trap (#8552)
  * [http_listener_v2] Stop() succeeds even if fails to start (#8502)
  * Unify comments style in the CPU input (#8605)
  * Fix readme link for line protocol in influx parser (#8610)
  * Add hex_key parameter for IPMI input plugin connection (#8524)
  * Add configurable number of 'most recent' date-stamped indices to gather in Elasticsearch input (#8543)
  * Add more verbose errors to influxdb output (#6061)
  * Allow globs (wildcards) in config for tags/fields in enum processor (#8598)
  * [ethtool] interface_up field added (#8590)
  * changed TestThreadStats acc to wait for 2 and added warning comment (#8592)
  * Add wildcard tags json parser support (#8579)
  * update inputs.influxdb readme (#8569)
  * Revert "Update grok package to support for field names containing '-' and '.' (#8276)"
  * Revert "disable flakey grok test for now"
  * fix potential issue with race condition (#8577)
  * fix issue with mqtt concurrent map write (#8562)
  * Added Glob pattern matching for "Windows Services" plugin (#8575)
  * Add prometheus remote write serializer (#8360)
  * Typo in INPUTS.md (#8573)
  * Remove duplicated field "revision" from ecs_task because it's already defined as a tag there (#8574)
  * fix crash when socket_listener receiving invalid data (#8551)
  * Graphite tags parser (#8564)
  * Update json parser readme (#8532)
  * Add per user metrics to mysql input (#6132)
  * Fix typo in CONTRIBUTING.md (#8528)
  * Fixing issue with missing metrics when pod has only pending containers (#8472)
  * fix edge case in aerospike plugin where an expected hex string was converted to integer if all digits (#8542)
  * [inputs.github] Add query of pull-request statistics (#8500)
  * New Intel PowerStat input plugin (#8488)
  * Update string parsing of allocatable cpu cores in kube_inventory (#8512)
* Wed Mar  3 2021 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.17.3:
  * plugins/filestat: Skip missing files (#7316)
  * Update go version to 1.15.8 (#8868)
  * Bump github.com/gopcua/opcua from 0.1.12 to 0.1.13 (#8744)
  * outputs/warp10: url encode comma in tags value (#8657)
  * inputs.x509_cert: Fix timeout issue  (#8824)
  * update min Go version in Telegraf readme (#8846)
  * Fix reconnection issues mqtt (#8821)
  * Validate the response from InfluxDB after writing/creating a database to avoid json parsing panics/errors (#8775)
  * Expose v4/v6-only connection-schemes through GosnmpWrapper (#8804)
  * adds missing & to flush_jitter output ref (#8838)
  * Sort and timeout is deadline (#8839)
  * Update README for inputs.ping with correct cmd for native ping on Linux (#8787)
  * Update go-ping to latest version (#8771)
* Wed Mar  3 2021 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.17.2:
  * Set interface for native (#8770)
  * Resolve regression, re-add missing function (#8764)
* Wed Mar  3 2021 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.17.1:
  * avoid issues with vendored dependencies when running make
  * [outputs.influxdb_v2] add exponential backoff, and respect client error responses (#8662)
  * add line about measurement being specified in docs (#8734)
  * Fix issue with elasticsearch output being really noisy about some errors (#8748)
  * Add geoip external project reference
  * improve mntr regex to match user specific keys. (#7533)
  * Fix crash in lustre2 input plugin, when field name and value (#7967)
  * Update grok-library to v1.0.1 with dots and dash-patterns fixed. (#8673)
  * Use go-ping for "native" execution in Ping plugin (#8679)
  * fix x509 cert timeout issue (#8741)
  * Add setting to enable caching in ipmitool (#8335)
  * Bump github.com/nsqio/go-nsq from 1.0.7 to 1.0.8 (#8714)
  * Bump github.com/Shopify/sarama from 1.27.1 to 1.27.2 (#8715)
  * add kafka connect example to jolokia2 input (#8709)
  * Bump github.com/newrelic/newrelic-telemetry-sdk-go from 0.2.0 to 0.5.1 (#8712)
  * Add Event Log support for Windows (#8616)
  * update readme: prometheus remote write (#8683)
  * GNMI plugin should not take off the first character of field keys when no 'alias path' exists. (#8659)
  * Use the 'measurement' json field from the particle webhook as the measurment name, or if it's blank, use the 'name' field of the event's json. (#8609)
  * Procstat input plugin should use the same timestamp in all metrics in the same Gather() cycle. (#8658)
  * update data formats output docs (#8674)
  * Add timestamp column support to postgresql_extensible (#8602)
  * Added ability to define skip values in csv parser (#8627)
  * fix some annoying tests due to ports in use
  * Optimize SeriesGrouper & aggregators.merge (#8391)
  * Using mime-type in prometheus parser to handle protocol-buffer responses (#8545)
  * Input SNMP plugin - upgrade gosnmp library to version 1.29.0 (#8588)
  * Upgrade circle-ci config to v2.1 (#8621)
  * remove redundant reference to docs in data formats docs (#8652)
  * alphabetize external plugins list (#8647)
  * Open Hardware Monitor (#8646)
  * outputs/http: add option to control idle connection timeout (#8055)
  * update influxdb_v2 config documentation in main (#8618)
  * update intel powerstat readme (#8600)
  * common/tls: Allow specifying SNI hostnames (#7897)
  * Fix spelling and clarify docs (#8164)
  * fixed formatting (+1 squashed commit) (#8541)
  * Provide method to include core count when reporting cpu_usage in procstat input (#6165)
  * Add support for an inclusive job list in Jenkins plugin (#8287)
  * improve the error log message for snmp trap (#8552)
  * [http_listener_v2] Stop() succeeds even if fails to start (#8502)
  * Unify comments style in the CPU input (#8605)
  * Fix readme link for line protocol in influx parser (#8610)
  * Add hex_key parameter for IPMI input plugin connection (#8524)
  * Add more verbose errors to influxdb output (#6061)
* Wed Mar  3 2021 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.17.0:
  * Allow globs (wildcards) in config for tags/fields in enum processor (#8598)
  * [ethtool] interface_up field added (#8590)
  * changed TestThreadStats acc to wait for 2 and added warning comment (#8592)
  * Add wildcard tags json parser support (#8579)
  * update inputs.influxdb readme (#8569)
  * update etc/telegraf.conf
  * Revert "Update grok package to support for field names containing '-' and '.' (#8276)"
  * Revert "disable flakey grok test for now"
  * fix potential issue with race condition (#8577)
  * fix issue with mqtt concurrent map write (#8562)
  * Added Glob pattern matching for "Windows Services" plugin (#8575)
  * Add prometheus remote write serializer (#8360)
  * Typo in INPUTS.md (#8573)
  * Remove duplicated field "revision" from ecs_task because it's already defined as a tag there (#8574)
  * fix crash when socket_listener receiving invalid data (#8551)
  * Graphite tags parser (#8564)
  * Update json parser readme (#8532)
  * Add per user metrics to mysql input (#6132)
  * Fix typo in CONTRIBUTING.md (#8528)
  * Fixing issue with missing metrics when pod has only pending containers (#8472)
  * fix edge case in aerospike plugin where an expected hex string was converted to integer if all digits (#8542)
  * [inputs.github] Add query of pull-request statistics (#8500)
  * New Intel PowerStat input plugin (#8488)
  * Update string parsing of allocatable cpu cores in kube_inventory (#8512)
  * disable flakey grok test for now
  * Fixed misspelled check for datacenter (#8505)
  * feat: add build number field to jenkins_job measurement (#8038)
  * Add percentiles to the ping plugin (#7345)
  * Added tags for monitoring readable secondaries for Azure SQL MI (#8369)
  * SQL Server HA/DR Availability Group queries (#8379)
  * Add initialization example to mock-plugin. (#8520)
  * Add support to convert snmp hex strings to integers (#8426)
  * Update kube_inventory readme (#8510)
  * Update circleci mac golang version (#8516)
  * Adding support for new lines in influx line protocol fields. (#8499)
  * Add configurable Max TTL duration for statsd input plugin entries (#8509)
  * Fix carbon2 tests (#8254)
  * fixed network test (#8498)
  * Add configurable timeout to bind input plugin http call (#8508)
  * Added is_primary_replica for monitoring readable secondaries for Azure SQL DB (#8368)
  * sqlAzureMIRequests - remove duplicate column [session_db_name] (#8462)
  * Add column measurement_db_type to output of all queries if not empty (#8464)
  * Add node groups to opcua input plugin (#8389)
  * Add a parser plugin for prometheus (#7778)
  * Update grok package to support for field names containing '-' and '.' (#8276)
  * add to starlark readme
  * add support for linux/ppc64le (#8432)
  * Add FLOAT64-IEEE support to inputs.modbus (#8361) (by @Nemecsek) (#8474)
  * Add the shared state to the global scope to get previous data (#8447)
  * Log SubscribeResponse_Error message and code. #8482 (#8483)
  * Removed outdated information about Windows support (#7971)
  * Add dataset metrics to zfs input (#8383)
  * add log warning to starlark drop-fields example
  * update godirwalk to v1.16.1 (#7987)
  * Support Riemann-Protobuff Listener (#8163)
  * Starlark example dropbytype (#8438)
  * Added "name" parameter to NATS output plugin (#8429)
  * proxy support for http input (#8477)
  * Translate snmp field values (#8466)
  * Update CONTRIBUTING.md
  * Fix typo in column name (#8468)
  * [php-fpm] Fix possible "index out of range" (#8461)
  * Enable kafka zstd compression and idempotent writes (#8435)
  * Fix tests for Windows - part 1 (#8414)
  * Add response_time to monit plugin (#8056)
  * update to go 1.15.5 (#8446)
  * Add rate and interval to the basicstats aggregator plugin (#8428)
  * Update mdlayher/apcupsd dependency (#8444)
  * Show how to return a custom error with the Starlark processor (#8439)
  * keep field name as is for csv timestamp column (#8440)
  * Add DriverVersion and CUDA Version to output (#8436)
  * Show how to return several metrics with the Starlark processor (#8423)
  * fix config issue with tags (#8419)
  * Support logging in starlark (#8408)
  * add kinesis output to external plugins list (#8315)
  * Add non-retryable debug logging (#8406)
  * Wavefront output should distinguish between retryable and non-retryable errors (#8404)
  * Allow to catch errors that occur in the apply function (#8401)
  * Fix parsing of multiple files with different headers (#6318). (#8400)
  * proxmox: ignore QEMU templates and iron out a few bugs (#8326)
  * systemd_units: add --plain to command invocation (#7990) (#7991)
  * fix links in external plugins readme (#8307)
  * Fix minor typos in readmes (#8370)
  * Revert "fix to start Telegraf from Linux systemd.service"
  * Fix SMART plugin to recognize all devices from config (#8374)
  * fix to start Telegraf from Linux systemd.service
  * Add OData-Version header to requests (#8288)
  * fixes config issue #8362 (#8364)
  * shorten config (#7583)
  * Prydin issue 8169 (#8357)
  * On-prem fix for #8324 (#8356)
  * [output.wavefront] Introduced "immediate_flush" flag (#8165)
  * Initial Yandex.Cloud monitoring (#8296)
  * added support for bytes encoding (#7938)
  * Update jwt-go module to address CVE-2020-26160 (#8337)
  * fix plugins/input/ras test (#8350)
  * Fixed a bug with the state map in Dynatrace Plugin (#8329)
  * SQL Server Azure PerfCounters Fix (#8331)
  * kafka sasl-mechanism auth support for SCRAM-SHA-256, SCRAM-SHA-512, GSSAPI (#8318)
  * SQL Server - PerformanceCounters - removed synthetic counters (#8325)
  * SQL Server - server_properties added sql_version_desc (#8324)
  * Disable RAS input plugin on specific Linux architectures: mips64, mips64le, ppc64le, riscv64 (#8317)
  * processes: fix issue with stat no such file/dir (#8309)
  * fix issue with PDH_CALC_NEGATIVE_DENOMINATOR error (#8308)
  * RAS plugin - fix for too many open files handlers (#8306)
  * A new Logz.io output plugin (#8202)
  * Get the build version from a static file
  * Update next_version to 1.17.0
  * Sumo Logic output plugin: fix unparsable config.Size from sample config (#8243)
  * Fix wrong memory measurements of containers and vms (#8290)
  * New input plugin for RAS with fixed GLIBC issue (#8293)
  * fix issue with phpfpm url usage (#8292)
  * Update sarama library to 1.27.1 (#8289)
  * sqlAzureMIResourceStats - added sorting (#8286)
  * Fix using empty string as the namespace prefix in azure_monitor output plugin (#8282)
  * Fix Event timestamps (#8216)
  * Add support for fields and protocol lookups in port_name. (#8157)
  * fix flakey proc test (#8279)
  * Skip statically linked program during glibc version check (#8280)
  * remove unused dependency from list
  * Add glibc version check for linux builds (#8278)
  * go mod tidy
  * temporarily remove RAS plugin
  * http_response: match on status code (#8032)
  * turn gzip on by default for InfluxDB v1 output (#8269)
  * Dynatrace Output Plugin: Fixed behaviour when state map is cleared (#8251)
  * Add the Timestream Output Plugin  (#8239)
  * fix issue with loading processor config from execd (#8274)
  * cleanup Intel RDT readme (#8268)
  * fix(exec): fix typo in exec readme (#8265)
  * fix(ras): update readme title (#8266)
  * add plugin documentation
  * execd-systemd-timings: Add telegraf-execd-systemd-timings to the list (#8263)
  * Sumo Logic output plugin: only support HTTP POST (#8262)
  * New sql server queries (on-prem) - refactoring and formatting (#8172)
  * Update README.md (#8049)
  * fix ci test
  * add converter test
  * fix flakey tests
* Wed Mar  3 2021 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.16.3:
  * Log SubscribeResponse_Error message and code. #8482 (#8483)
  * add log warning to starlark drop-fields example
  * update godirwalk to v1.16.1 (#7987)
  * Starlark example dropbytype (#8438)
  * Fix typo in column name (#8468)
  * [php-fpm] Fix possible "index out of range" (#8461)
  * Update mdlayher/apcupsd dependency (#8444)
  * Show how to return a custom error with the Starlark processor (#8439)
  * keep field name as is for csv timestamp column (#8440)
  * Add DriverVersion and CUDA Version to output (#8436)
  * Show how to return several metrics with the Starlark processor (#8423)
  * Support logging in starlark (#8408)
  * add kinesis output to external plugins list (#8315)
  * Add non-retryable debug logging (#8406)
  * Wavefront output should distinguish between retryable and non-retryable errors (#8404)
  * Allow to catch errors that occur in the apply function (#8401)
* Wed Mar  3 2021 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.16.2:
  * Fix parsing of multiple files with different headers (#6318). (#8400)
  * proxmox: ignore QEMU templates and iron out a few bugs (#8326)
  * systemd_units: add --plain to command invocation (#7990) (#7991)
  * fix links in external plugins readme (#8307)
  * Fix minor typos in readmes (#8370)
  * Fix SMART plugin to recognize all devices from config (#8374)
  * Add OData-Version header to requests (#8288)
  * misc tests
  * Prydin issue 8169 (#8357)
  * On-prem fix for #8324 (#8356)
  * [output.wavefront] Introduced "immediate_flush" flag (#8165)
  * added support for bytes encoding (#7938)
  * Update jwt-go module to address CVE-2020-26160 (#8337)
  * fix plugins/input/ras test (#8350)
  * Fixed a bug with the state map in Dynatrace Plugin (#8329)
* Wed Mar  3 2021 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.16.1:
  * common.kafka kafka sasl-mechanism auth support for SCRAM-SHA-256, SCRAM-SHA-512, GSSAPI (#8318)
  * inputs.sqlserver SQL Server Azure PerfCounters Fix (#8331)
  * inputs.sqlserver SQL Server - PerformanceCounters - removed synthetic counters (#8325)
  * inputs.sqlserver SQL Server - server_properties added sql_version_desc (#8324)
  * inputs.ras Disable RAS input plugin on specific Linux architectures: mips64, mips64le, ppc64le, riscv64 (#8317)
  * inputs.processes processes: fix issue with stat no such file/dir (#8309)
  * inputs.win_perf_counters fix issue with PDH_CALC_NEGATIVE_DENOMINATOR error (#8308)
  * inputs.ras RAS plugin - fix for too many open files handlers (#8306)
* Wed Mar  3 2021 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.16.0:
  * Set 1.16.0 release date
  * Update etc/telegraf.conf
  * go mod tidy
  * Sumo Logic output plugin: fix unparsable config.Size from sample config (#8243)
  * Fix wrong memory measurements of containers and vms (#8290)
  * New input plugin for RAS with fixed GLIBC issue (#8293)
  * fix issue with phpfpm url usage (#8292)
  * Add support for fields and protocol lookups in port_name. (#8157)
  * go mod tidy
  * turn gzip on by default for InfluxDB v1 output (#8269)
  * fix(exec): fix typo in exec readme (#8265)
  * Update README.md (#8049)
  * fix ci test
  * add converter test
  * Update sarama library to 1.27.1 (#8289)
  * sqlAzureMIResourceStats - added sorting (#8286)
  * Fix using empty string as the namespace prefix in azure_monitor output plugin (#8282)
  * Fix Event timestamps (#8216)
  * fix flakey tests
  * fix flakey proc test (#8279)
  * Skip statically linked program during glibc version check (#8280)
  * remove unused dependency from list
  * Add glibc version check for linux builds (#8278)
  * go mod tidy
  * temporarily remove RAS plugin
  * http_response: match on status code (#8032)
  * Dynatrace Output Plugin: Fixed behaviour when state map is cleared (#8251)
  * Add the Timestream Output Plugin  (#8239)
  * fix issue with loading processor config from execd (#8274)
  * cleanup Intel RDT readme (#8268)
  * execd-systemd-timings: Add telegraf-execd-systemd-timings to the list (#8263)
  * Sumo Logic output plugin: only support HTTP POST (#8262)
  * add plugin documentation
  * New sql server queries (on-prem) - refactoring and formatting (#8172)
  * Update etc/telegraf.conf
  * Add agent host tag configuration option (#8082)
  * Fixed almost all bugs found by LGTM analysis platform (#8240)
  * fix carbon tests
  * Multiple escaping occurs on Jenkins URLs at certain folder depth (#8048)
  * Fix bool serialization when using carbon2 (#8162)
  * add plugin authors to changelog
  * remote duplicate changelog entries
  * update to go 1.15 (#8220)
  * New sql server queries (Azure) - refactoring and formatting (#8186)
  * change influxdb port 9999 to 8086 (#8198)
  * input consul - added metric_version flag (#7875)
  * Fix carbon2 serializer not falling through to field separate when carbon2_format field is unset (#8201)
  * Fixed Query mapping (#8200)
  * add min telegraf to plugin readme (#8223)
  * New input plugin for RAS (Reliability, Availability and Serviceability) (#8114)
  * New input plugin for Intel RDT (Intel Resource Director Technology) (#8150)
  * Update telegraf.conf
  * update gopsutil: fix procstat performance regression (#8210)
  * fix(win_eventlog): fixing config (#8209)
  * Add note about json processing to docs
  * Missing ServiceNow metrics in DATA_FORMATS_OUTPUT.md (#8205)
  * Dynatrace Output: change handling of monotonic counters (#8159)
  * fix: plugins/parsers/influx: avoid ParseError.Error panic (#8177)
  * Fix vulnerabilities found in BDBA scan (#8199)
  * feat: add functionality to get values from redis commands (#8196)
  * Implement AWS CloudWatch Input Plugin ListMetrics API calls to use Active Metric Filter (#7894)
  * add json parsing support to starlark (#8168)
  * Sumo Logic output plugin: carbon2 default to include field in metric (#8132)
  * If the community string is available, add it as a tag (#8189)
  * Windows eventlog input plugin (based on #7020) (#8000)
  * Semigroupoid multiline (#8167) (#8190)
  * fix panic on streaming processers using logging (#8176)
  * Add more missing NVMe attributes to smart plugin (#8113)
  * Fix Sumo Logic output plugin not splitting requests properly (#25) (#8115)
  * Added more performance counters to SqlServer input plugin (#8120)
  * Starlark readme url fix
  * minor docs cleanup
  * update shim docs to point users in the right direction
  * Increasing the metric buffer (#8145)
  * Remove Event field as it is causing issues with pre-trained source types (#8039)
  * influxdb_v2_listener - add /ready route (#8133)
  * Add octoprint to list (#8131)
  * add influxdata slack icon to telegraf readme (#8126)
  * Sort plugin name lists for output (#8127)
  * Doc update: Fix main.go shim example link (#8123)
  * Influxdb v2 listener (#7828)
  * Fix bug fix typo in changelog (#8117)
  * update 1.16 changelog with new plugins (#8107)
  * SNMP input plugin: document partial table collection (#8104)
  * Carbon2 configuration option - include field in metric name (#8094)
  * Sumo Logic output plugin (#8023)
  * Revert "update influxdb v2 port"
  * update influxdb v2 port
  * Database_type config to Split up sql queries by engine type (#7934)
  * added force_document_id option to ES output enable resend data and avoiding duplicated ES documents, fix #7891 (#8019)
  * [fix] add missing error check for HTTP req failure (#8071)
  * add nsd input plugin (#7822)
  * Fix external plugin docs links (#8081)
  * Opcua cleanup (#8076)
  * update opcua readme (#8075)
  * add tagpass/tagdrop note in docs (#8053)
  * add guidelines run to external plugins with execd (#8054)
  * Fix docker-image make target (#8005)
  * Add OPC UA input plugin (#8009)
  * Update gopsutils to v.2.20.7 (#8073)
  * Fix CI AppVeyor 'make check' errors for go 1.15 on windows (#8061)
  * fix bug in shim logger affecting AddError (#8052)
  * fix docker build. update dockerfiles to Go 1.14 (#8051)
  * Add set, and histogram reporting to aerospike telegraf plugin (#8025)
  * Create external plugins doc file and update contributing guide (#8001)
  * Add addTag debugging in ifname plugin (#8018)
  * vSphere Fixed missing clustername issue 7878 (#8026)
  * Fix string to int conversion in eventhub consumer (#8006)
  * improve the quality of starlark docs by executing them as tests (#8020)
  * Fix InsecureSkipVerify in Dynatrace Plugin (#8015)
  * Fix Ping Input plugin for FreeBSD's ping6 (#7861)
  * add example input/outputs to starlark examples (#7980)
  * Fix configuration.md formatting (#7965)
  * [agent] Cleanup duplicates in loaded plugins list (#7852)
  * [outputs.application_insights] Added the ability to set the endpoint url (#7134)
  * fix issue with shim use of config.Duration (#7996)
  * fix minor agent race condition around error messages (#7999)
  * fix flakey ticker test (#7997)
  * Dynatrace Plugin - Updated Documentation (#7994)
  * http_listener_v2: make http header tags case insensitive (#7986)
  * fix(readmes): updates to internal and proxmox readmes (#7982)
  * Update Support.md
  * Create Support.md
  * add label to feature request.
  * Update Bug_report.md
  * Proxmox plugin (#7922)
  * Dynatrace output plugin (#7881)
  * add additional metrics to clickhouse input plugin (#7904)
  * add pivot example for starlark processor (#7976)
  * fix(puppet): update broken link (#7977)
  * fix(ipmi): update link in readme (#7975)
  * chore: extend gitignore to ignore .DS_Store (#7974)
  * fix(readmes): standarize first line of readmes (#7973)
  * Updated http_response input plugin README.md (#7962)
  * fix(readmes): adding code block annotations (#7963)
  * rabbitmq: remove deprecated healthcheck (#7823) (#7920)
  * added new counter - Lock Timeouts (timeout > 0)/sec (#7808)
  * fix cloudwatch tests
  * Support for AWS Cloudwatch Alarms #7931 (#7932)
  * cleanup cloudwatch plugin (#7928)
  * Add details to connect to InfluxDB OSS 2 and Cloud 2 (#7953)
  * JSON does not support values NaN and Inf (#7908)
  * Add descriptions for measurement & fields (#7902)
  * Fixed title on New Relic README.md (#7948)
  * Fix tail following on EOF (#7927)
  * fix broken link to proc.c (#7918)
  * fixes issue with rpm /var/log/telegraf permissions (#7909)
  * MongoDB: Added new metric "pages written from cache" (#7870)
  * Fix/extend support of fixed point values on input (modbus plugin) (#7869)
  * jolokia: add some error message context (#7906)
  * fixed cgroups docu (#7889)
  * Fix arch name in deb/rpm builds (#7877)
  * shim logger improvements (#7865)
  * Fix defaults processor readme typos (#7873)
  * Recv next message after send returns EOF (#7872)
  * Update docker FAQ (#7868)
  * fix issue with execd restart_delay being ignored (#7867)
  * Add logic starlark example (#7864)
  * clarify docs and add warning if execd is misconfigured (#7866)
  * Print configuration for downloads page (#7862)
  * prefer testify error funcs over nil checks (#7857)
  * Fix suricata input docs (#7856)
  * ifname: avoid unpredictable conditions in getMap test (#7848)
  * Log after interval has elapsed; skip short intervals (#7854)
  * Initialize aggregation processors (#7853)
  * Update redfish docs with link (#7846)
  * Update telegraf.conf
  * ifname processor: expire old cached entries (#7838)
  * update go versions: 1.14.5, 1.13.13 (#7837)
  * Edit Starlark README (#7832)
  * Send metrics in FIFO order (#7814)
  * Add github.com/inabagumi/youtube-telegraf-plugin to list of external plugins (#7825)
  * Set log output before starting plugin (#7820)
  * fix bug with loading plugins in shim with no config (#7816)
  * Fix darwin package build flags (#7818)
  * Close file to ensure it has been flushed (#7819)
  * documentation: typo outputs cloud_pubsub (#7817)
  * fix typo in cloud_pubsub docs (#7815)
  * Add minimum version for new plugins (#7810)
  * Fix markdown syntax (#7806)
  * Fix typo in 1.15 release notes (#7804)
  * Fix tag package version
* Wed Mar  3 2021 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.15.4:
  * fix issue with loading processor config from execd (#8274)
  * fix panic on streaming processers using logging (#8176)
* Sat Sep 12 2020 Jeff Kowalczyk <jkowalczyk@suse.com>
- BuildRequires: golang(API) >= 1.13
  * Recommended format selects latest Provides: golang(API) = %%{api_version}
    satisfied by either go metapackage or go1.1x packages.
* Sat Sep 12 2020 dmueller@suse.com
- Update to version 1.15.3:
  * Revert "fix cloudwatch tests"
  * Update etc/telegraf.conf
  * [fix] add missing error check for HTTP req failure (#8071)
  * add tagpass/tagdrop note in docs (#8053)
  * Fix docker-image make target (#8005)
  * Fix CI AppVeyor 'make check' errors for go 1.15 on windows (#8061)
  * add release notes
  * fix bug in shim logger affecting AddError (#8052)
  * fix docker build. update dockerfiles to Go 1.14 (#8051)
  * docs fix
  * Create external plugins doc file and update contributing guide (#8001)
  * Add addTag debugging in ifname plugin (#8018)
  * vSphere Fixed missing clustername issue 7878 (#8026)
  * Fix string to int conversion in eventhub consumer (#8006)
  * improve the quality of starlark docs by executing them as tests (#8020)
  * Fix Ping Input plugin for FreeBSD's ping6 (#7861)
  * add example input/outputs to starlark examples (#7980)
  * Fix configuration.md formatting (#7965)
  * [outputs.application_insights] Added the ability to set the endpoint url (#7134)
  * fix issue with shim use of config.Duration (#7996)
  * fix minor agent race condition around error messages (#7999)
  * http_listener_v2: make http header tags case insensitive (#7986)
  * add pivot example for starlark processor (#7976)
  * fix(puppet): update broken link (#7977)
  * fix(ipmi): update link in readme (#7975)
  * chore: extend gitignore to ignore .DS_Store (#7974)
  * fix(readmes): standarize first line of readmes (#7973)
  * Updated http_response input plugin README.md (#7962)
  * added new counter - Lock Timeouts (timeout > 0)/sec (#7808)
  * fix cloudwatch tests
  * Support for AWS Cloudwatch Alarms #7931 (#7932)
  * Add details to connect to InfluxDB OSS 2 and Cloud 2 (#7953)
  * JSON does not support values NaN and Inf (#7908)
  * Add descriptions for measurement & fields (#7902)
  * Fixed title on New Relic README.md (#7948)
  * fix broken link to proc.c (#7918)
  * Fix/extend support of fixed point values on input (modbus plugin) (#7869)
  * jolokia: add some error message context (#7906)
  * fixed cgroups docu (#7889)
  * Update docker FAQ (#7868)
  * fixes issue with rpm /var/log/telegraf permissions (#7909)
  * Fix tail following on EOF (#7927)
  * Fix arch name in deb/rpm builds (#7877)
  * Set 1.15.0 release date
  * Add logic starlark example (#7864)
  * shim logger improvements (#7865)
  * Fix defaults processor readme typos (#7873)
  * Recv next message after send returns EOF (#7872)
  * fix issue with execd restart_delay being ignored (#7867)
  * clarify docs and add warning if execd is misconfigured (#7866)
  * fix bug with loading plugins in shim with no config (#7816)
  * Fix suricata input docs (#7856)
  * ifname: avoid unpredictable conditions in getMap test (#7848)
  * Log after interval has elapsed; skip short intervals (#7854)
  * Initialize aggregation processors (#7853)
  * Update redfish docs with link (#7846)
  * Update telegraf.conf
  * ifname processor: expire old cached entries (#7838)
  * update go versions: 1.14.5, 1.13.13 (#7837)
  * Edit Starlark README (#7832)
  * Send metrics in FIFO order (#7814)
  * Set log output before starting plugin (#7820)
  * Fix darwin package build flags (#7818)
  * Close file to ensure it has been flushed (#7819)
  * Add minimum version for new plugins (#7810)
  * Fix markdown syntax (#7806)
  * Fix typo in 1.15 release notes (#7804)
  * Fix tag package version
  * Update sample configuration
  * Add ifname processor plugin (#7763)
  * Traverse redfish api using resource links (#7722)
  * Fix test race in kafka_consumer (#7797)
  * Support utf-16 in file and tail inputs (#7792)
  * Add v3 metadata support to ecs input (#7154)
  * Fix inputs.execd readme links (#7791)
  * Fix data race in input plugin ping_windows
  * streaming processors docs update (#7786)
  * switch mac tests to Go 1.14 (#7784)
  * Fix flakey processors.execd test
  * Do not enable -race for GOARCH=386
  * Run all Go tests with flag -race
  * Fix data race in plugin output pubsub tests (#7782)
  * Shim refactor to support processors and output
  * Fix data race in tail input tests (#7780)
  * Update CHANGELOG.md
  * execd output (#7761)
  * Set user agent when requesting http config (#7752)
  * Accept decimal point when parsing kibana uptime (#7768)
  * Update common/tls import path
  * Update nginx_sts plugin readme
  * Add nginx_sts input plugin (#7205)
  * Rename cisco_telemetry_gnmi input to gnmi (#7695)
  * Allow overriding the collection_jitter and precision per input (#7762)
  * Fix data race in phpfpm initializing http client (#7738)
  * Set 1.14.5 release date
  * Allow histograms with no buckets and summary without quantiles (#7740)
  * Fix typo in elasticsearch input docs (#7764)
  * Only set version ldflags on tags
  * Update release notes
  * Allow any key usage type on x509 certificate (#7760)
  * Build packages in makefile (#7759)
  * Update github.com/tidwall/gjson (#7756)
  * reverse dns lookup processor (#7639)
  * remove streaming processors docs
  * clean up tests
  * address feedback
  * Return on toml parse errors instead of logging (#7751)
  * Update tls import path
  * Export internal/tls package for use in execd plugins (#7697)
  * Add laundry to mem input plugin on FreeBSD (#7736)
  * Fix data race in plugins/inputs/stackdriver/stackdriver_test.go (#7744)
  * Fix data race in plugins/inputs/suricata/suricata_test.go (#7745)
  * Fix data race in kafka_consumer_test.go (#7737)
  * Fix SNMP trap test race (#7731)
  * Fix incorrect Azure SQL DB server properties (#7715)
  * fix race
  * fix after rebase
  * remove processors/execd/examples/count.go
  * execd processor
  * Fix license check
  * Add starlark processor (#7660)
  * Add missing nvme attributes to smart plugin (#7575)
  * Add counter type to perfmon collector (#7712)
  * Skip overs errors in the output of the sensors command (#7718)
  * Remove master/slave terminology from tests (#7719)
  * Fix ping exit code handling on non-Linux (#7658)
  * Add redfish input plugin (#7082)
  * Add ability to add selectors as tags in kube_inventory (#7267)
  * Document that string fields do not produce prometheus metrics (#7644)
  * Remove trailing backslash management in sqlserver input (#7700)
  * Link to GJSON playground in json parser documentation (#7698)
  * Add 'batch' to mqtt output optional parameters (#7690)
  * Fail check-deps when differences are found (#7694)
  * Add state and readiness to kube_inventory pod metrics (#7691)
  * update CHANGELOG.md
  * procstat performance enhancement (#7686)
  * Mark unused agent options as deprecated
  * Fix processor initialization (#7693)
  * Update gNMI plugin readme (#7685)
  * Remove trailing backslash from tag keys/values (#7652)
  * Improve sqlserver input compatibility with older server versions (#7495)
  * Fix race issue in tick_test.go (#7663)
  * Flaky shim test (#7656)
  * link to glob pattern docs (#7657)
  * Set 1.14.4 release date
  * Add ability to collect response body as field with http_response (#7596)
  * Add timezone configuration to csv data format (#7619)
  * Change rpm dist packaging type for arm64 to aarch64 (#7645)
  * Update to github.com/shirou/gopsutil v2.20.5 (#7641)
  * Fix source field for icinga2 plugin (#7651)
  * Add video codec stats to nvidia-smi (#7646)
  * Update CHANGELOG.md
  * fix issue with stream parser blocking when data is in buffer (#7631)
  * add support for streaming processors (#7634)
  * Add tags to snmp_trap input for context name and engine ID (#7633)
  * Clarify use of multiple mqtt broker servers
  * Add SNMPv3 trap support to snmp_trap input plugin (#7294)
  * Add support for Solus distribution to maintainer scripts (#7585)
  * Fix typo in queue depth example of diskio plugin (#7613)
  * Add support for env variables to shim config (#7603)
  * Add support for once mode; run processors and aggregators during test (#7474)
  * Update AGGREGATORS_AND_PROCESSORS.md (#7599)
  * Add github.com/inabagumi/twitter-telegraf-plugin to list of external plugins
  * Fix segmentation violation on connection failed (#7593)
  * Add processor to look up service name by port (#7540)
  * make sure parse error includes offending text (#7561)
  * Update docs for newrelic output
  * Add newrelic output plugin  (#7019)
  * Allow collection of HTTP Headers in http_response input (#7405)
  * Update to Go 1.14.3 with testing using 1.13.11 (#7564)
  * Exclude csv_timestamp_column and csv_measurement_column from fields (#7572)
  * fix go version check (#7562)
  * Fix the typo in `gcc_pu_fraction` to `gc_cpu_fraction` (#7573)
  * Fix numeric to bool conversion in converter (#7579)
  * Add defaults processor to set default field values (#7370)
  * Add option to disable mongodb cluster status (#7515)
  * Fix typos in sqlserver input (#7524)
  * Use updated clock package to resolve test failures (#7516)
  * fix randomly failing CI test (#7514)
  * Add cluster state integer to mongodb input (#7489)
  * Add configurable separator graphite serializer and output (#7545)
  * Fix instance name resolution in performance counter query (#7526)
  * Set 1.14.3 release date
  * Close HTTP2 connections on timeout in influxdb outputs (#7517)
  * Fix negative value parsing in impi_sensor input (#7541)
  * Fix assorted spelling mistakes (#7507)
  * Fix documentation of percent_packet_loss field (#7510)
  * Update docs for execd plugins (#7465)
  * Update procstat pid_tag documentation
  * Fix spelling errors in comments and documentation (#7492)
  * Add truncate_tags setting to wavefront output (#7503)
  * Add authentication support to the http_response input plugin (#7491)
  * Handle multiple metrics with the same timestamp in dedup processor (#7439)
  * Add additional fields to mongodb input (#7321)
  * Add integer support to enum processor (#7483)
  * Fix typo in Windows service description (#7486)
  * Add field creation to date processor and integer unix time support (#7464)
  * Add cpu query to sqlserver input (#7359)
  * Rework plugin tickers to prevent drift and spread write ticks (#7390)
  * Update datadog output documentation (#7467)
  * Use docker log timestamp as metric time (#7434)
  * fix issue with execd-multiline influx line protocol (#7463)
  * Add information about HEC JSON format limitations and workaround (#7459)
  * Rename measurement to sqlserver_volume_space (#7457)
  * shim improvements for docs, clean quit, and slow readers (#7452)
  * Fix gzip support in socket_listener with tcp sockets (#7446)
  * Remove debug fields from spunkmetric serializer (#7455)
  * Fix filepath processor link in changelog (#7454)
  * Support Go execd plugins with shim (#7283)
  * Add filepath processor plugin (#7418)
  * Add ContentEncoder to socket_writer for datagram sockets (#7417)
  * Sflow rework (#7253)
  * Use same timestamp for all objects in arrays in the json parser (#7412)
  * Set 1.14.2 release date
  * Allow CR and FF inside of string fields and fix parser panic (#7427)
  * Fix typo in name of gc_cpu_fraction field (#7425)
  * Run create database query once per database (#7333)
  * Ignore fields with NaN or Inf floats in the JSON serializer (#7426)
  * Fix interfaces with pointers (#7411)
  * Document distinction between file and tail inputs (#7353)
  * Update changelog
  * Fix shard indices reporting in elasticsearch input (#7332)
  * Update changelog
  * Fix string to int64 conversion for SNMP input (#7407)
  * Update nvidia-smi README for Windows users (#7399)
  * Extract target as a tag for each rule in iptables input (#7391)
  * Fix dimension limit on azure_monitor output (#7336)
  * Use new higher per request limit for cloudwatch GetMetricData (#7335)
  * Add support for MDS and RGW sockets to ceph input (#6915)
  * Add option to save retention policy as tag in influxdb_listener (#7356)
  * Trim instance tag in the sqlserver performance counters query (#7351)
  * Fix vSphere 6.7 missing data issue (#7233)
  * Update modbus readme
  * Add retry when slave is busy to modbus input (#7271)
  * fix issue with closing flush signal channel (#7384)
  * Use the product token for the user agent in more locations (#7378)
  * Update github.com/aws/aws-sdk-go (#7373)
  * add support for SIGUSR1 to trigger flush (#7366)
  * add another grok example for custom timestamps (#7367)
  * Fibaro input: for battery operated devices, add battery level scraping (#7319)
  * Deprecate logparser input and recommend tail input as replacement (#7352)
  * Adjust heading level in the filtering examples to allow linking
  * Set 1.14.1 release date
  * Add reading bearer token from a file to http input (#7304)
  * Fix exclude database and retention policy tags is shared (#7323)
  * Fix status path when using globs in phpfpm (#7324)
  * Regenerate telegraf.conf
  * Fix error in docs about exclude_retention_policy_tag (#7311)
  * Fix Name field in template processor (#7258)
  * Deploy telegraf configuration as a "non config" file (#7250)
  * Fix export timestamp not working for prometheus on v2 (#7289)
  * Sql Server - Disk Space Measurement (#7214)
  * Add series cardinality warning to sflow readme (#7285)
  * Improve documentation for the Metric interface (#7256)
  * Update permission docs on postfix input (#7255)
  * Document kapacitor_alert and kapacitor_cluster measurements (#7278)
  * Add OPTION RECOMPILE for perf reasons due to temp table (#7242)
  * Support multiple templates for graphite serializers (#7136)
  * Add possibility to specify measurement per register (#7231)
  * Add limit to number of undelivered lines to read ahead in tail (#7210)
  * Add docs for how to handle errors in check-deps script (#7243)
  * Add support for 64-bit integer types to modbus input (#7225)
  * Set 1.14.0 release date
  * Apply ping deadline to dns lookup (#7140)
  * Add ability to specify HTTP Headers in http_listener_v2 which will added as tags (#7223)
  * Fix 'nil' file created by Makefile on Windows (#7224)
  * Add additional concurrent transaction information (#7193)
  * Add commands stats to mongodb input plugin (#6905)
  * Fix url encoding of job names in jenkins input plugin (#7211)
  * Update next_version on master to 1.15.0
  * Update etc/telegraf.conf
  * Fix datastore_include option in vsphere input readme
  * Update github.com/prometheus/client_golang to latest (#7200)
  * Update etc/telegraf.conf
  * Update google.cloud.go to latest (#7199)
* Wed May 27 2020 tuukka.pasanen@ilmi.fi
- Update to use _service file to make depency building easier
- Require GO version 1.12 if it in future gets too old it should we
  set to correct version
- Update to version 1.14.3:
  * Set 1.14.3 release date
  * Update changelog
  * Close HTTP2 connections on timeout in influxdb outputs (#7517)
  * Fix negative value parsing in impi_sensor input (#7541)
  * Update changelog
  * Handle multiple metrics with the same timestamp in dedup processor (#7439)
  * Update changelog
  * Use same timestamp for all objects in arrays in the json parser (#7412)
  * Set 1.14.2 release date
  * Update changelog
* Fri Apr  3 2020 Jeff Kowalczyk <jkowalczyk@suse.com>
- Remove carried patch for Generic SQL output plugin. The upstream PR
  https://github.com/influxdata/telegraf/pull/4205 that is the source of this
  patch hasn't accepted it since 2018, with no recent activity. Dropping the
  patch as there are no known users.
  * drop 0001-Generic-SQL-output-plugin-for-Telegraf.patch unified original
  * drop 0001-plugins-outputs-all-all.go-Generic-SQL-output-plugin.patch split
  * drop 0002-plugins-outputs-sql-README.md-Generic-SQL-output-plu.patch split
  * drop 0003-plugins-outputs-sql-sql.go-Generic-SQL-output-plugin.patch split
  * drop 0004-plugins-outputs-sql-sql_test.go-Generic-SQL-output-p.patch split
  * drop 0005-README.md-Generic-SQL-output-plugin-for-Telegraf-pat.patch split
  * packaging: telegraf-1.13.4 still uses the dep dependency tool, now
    documented as a comment in the .spec. An upcoming telegraf release will
    complete the transition to go modules, at which point packaging will be
    updated accordingly.
* Wed Mar  4 2020 Johannes Kastl <kastl@b1-systems.de>
- create directory /etc/telegraf/telegraf.d/
* Sat Feb 29 2020 Johannes Kastl <kastl@b1-systems.de>
- update to 1.13.4
  Bugfixes
  - #6988: Parse NaN values from summary types in prometheus input.
  - #6820: Fix pgbouncer input when used with newer pgbouncer versions.
  - #6913: Support up to 8192 stats in the ethtool input.
  - #7060: Fix perf counters collection on named instances in sqlserver input.
  - #6926: Use add time for prometheus expiration calculation.
  - #7057: Fix inconsistency with input error counting in internal input.
  - #7063: Use the same timestamp per call if no time is provided in prometheus input.
* Sat Feb 29 2020 Johannes Kastl <kastl@b1-systems.de>
- update to 1.13.3
  Bugfixes
  - #5744: Fix kibana input with Kibana versions greater than 6.4.
  - #6960: Fix duplicate TrackingIDs can be returned in queue consumer plugins.
  - #6913: Support up to 4096 stats in the ethtool input.
  - #6973: Expire metrics on query in addition to on add.
* Sat Feb 29 2020 Johannes Kastl <kastl@b1-systems.de>
- update to 1.13.2
  Bugfixes
  - #2652: Warn without error when processes input is started on Windows.
  - #6890: Only parse certificate blocks in x509_cert input.
  - #6883: Add custom attributes for all resource types in vsphere input.
  - #6899: Fix URL agent address form with udp in snmp input.
  - #6619: Change logic to allow recording of device fields when attributes is false.
  - #6903: Do not add invalid timestamps to kafka messages.
  - #6906: Fix json_strict option and set default of true.
* Sat Feb 29 2020 Johannes Kastl <kastl@b1-systems.de>
- update to 1.13.1
  Bugfixes
  - #6788: Fix ServerProperty query stops working on Azure after failover.
  - #6803: Add leading period to OID in SNMP v1 generic traps.
  - #6823: Fix missing config fields in prometheus serializer.
  - #6694: Fix panic on connection loss with undelivered messages in mqtt_consumer.
  - #6679: Encode query hash fields as hex strings in sqlserver input.
  - #6345: Invalidate diskio cache if the metadata mtime has changed.
  - #6800: Show platform not supported warning only on plugin creation.
  - #6814: Fix rabbitmq cannot complete gather after request error.
  - #6846: Fix /sbin/init --version executed on Telegraf startup.
  - #6847: Use last path element as field key if path fully specified.
* Sat Feb 29 2020 Johannes Kastl <kastl@b1-systems.de>
- update to 1.13.0
  - rebased patch 0005-README.md-Generic-SQL-output-plugin-for-Telegraf-pat.patch
  - changelog:
    Release Notes
  - Official packages built with Go 1.13.5.
  - The prometheus input and prometheus_client output have a new mapping to
  - and from Telegraf metrics, which can be enabled by setting metric_version = 2.
  - The original mapping is deprecated. When both plugins have the same setting,
  - passthrough metrics will be unchanged. Refer to the prometheus input for
  - details about the mapping.
    New Inputs
  - azure_storage_queue - Contributed by @mjiderhamn
  - ethtool - Contributed by @philippreston
  - snmp_trap - Contributed by @influxdata
  - suricata - Contributed by @satta
  - synproxy - Contributed by @rfrenayworldstream
  - systemd_units - Contributed by @benschweizer
    New Processors
  - clone - Contributed by @adrianlzt
    New Aggregators
  - merge - Contributed by @influxdata
    Features
  - #6326: Add per node memory stats to rabbitmq input.
  - #6361: Add ability to read query from file to postgresql_extensible input.
  - #5921: Add replication metrics to the redis input.
  - #6177: Support NX-OS telemetry extensions in cisco_telemetry_mdt.
  - #6415: Allow graphite parser to create Inf and NaN values.
  - #6434: Use prefix base detection for ints in grok parser.
  - #6465: Add more performance counter metrics to sqlserver input.
  - #6476: Add millisecond unix time support to grok parser.
  - #6473: Add container id as optional source tag to docker and docker_log input.
  - #6504: Add lang parameter to OpenWeathermap input plugin.
  - #6540: Log file open errors at debug level in tail input.
  - #6553: Add timeout option to cloudwatch input.
  - #6549: Support custom success codes in http input.
  - #6530: Improve ipvs input error strings and logging.
  - #6532: Add strict mode to JSON parser that can be disable to ignore invalid items.
  - #6543: Add support for Kubernetes 1.16 and remove deprecated API usage.
  - #6283: Add gathering of RabbitMQ federation link metrics.
  - #6356: Add bearer token defaults for Kubernetes plugins.
  - #5870: Add support for SNMP over TCP.
  - #6603: Add support for per output flush jitter.
  - #6650: Add a nameable file tag to file input plugin.
  - #6640: Add Splunk MultiMetric support.
  - #6680: Add support for sending HTTP Basic Auth in influxdb input
  - #5767: Add ability to configure the url tag in the prometheus input.
  - #5767: Add prometheus metric_version=2 mapping to internal metrics/line protocol.
  - #6703: Add prometheus metric_version=2 support to prometheus_client output.
  - #6660: Add content_encoding compression support to socket_listener.
  - #6689: Add high resolution metrics support to CloudWatch output.
  - #6716: Add SReclaimable and SUnreclaim to mem input.
  - #6695: Allow multiple certificates per file in x509_cert input.
  - #6686: Add additional tags to the x509 input.
  - #6703: Add batch data format support to file output.
  - #6688: Support partition assignement strategy configuration in kafka_consumer.
  - #6731: Add node type tag to mongodb input.
  - #6669: Add uptime_ns field to mongodb input.
  - #6735: Support resolution of symlinks in filecount input.
  - #6746: Set message timestamp to the metric time in kafka output.
  - #6740: Add base64decode operation to string processor.
  - #6790: Add option to control collecting global variables to mysql input.
    Bugfixes
  - #6484: Show correct default settings in mysql sample config.
  - #6583: Use 1h or 3h rain values as appropriate in openweathermap input.
  - #6573: Fix not a valid field error in Windows with nvidia input.
  - #6614: Fix influxdb output serialization on connection closed.
  - #6690: Fix ping skips remaining hosts after dns lookup error.
  - #6684: Log mongodb oplog auth errors at debug level.
  - #6705: Remove trailing underscore trimming from json flattener.
  - #6421: Revert change causing cpu usage to be capped at 100 percent.
  - #6523: Accept any media type in the prometheus input.
  - #6769: Fix unix socket dial arguments in uwsgi input.
  - #6757: Replace colon chars in prometheus output labels with metric_version=1.
  - #6773: Set TrimLeadingSpace when TrimSpace is on in csv parser.
* Sat Feb 29 2020 Johannes Kastl <kastl@b1-systems.de>
- split up patch 0001-Generic-SQL-output-plugin-for-Telegraf.patch
  (from https://github.com/influxdata/telegraf/pull/4205)
  into multiple patches:
  0001-plugins-outputs-all-all.go-Generic-SQL-output-plugin.patch
  0002-plugins-outputs-sql-README.md-Generic-SQL-output-plu.patch
  0003-plugins-outputs-sql-sql.go-Generic-SQL-output-plugin.patch
  0004-plugins-outputs-sql-sql_test.go-Generic-SQL-output-p.patch
  0005-README.md-Generic-SQL-output-plugin-for-Telegraf-pat.patch
* Wed Dec 18 2019 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to release 1.12.6
  Refs boo#1159288 SLES customer request for updated version
  * v1.12.6 [2019-11-19]
  * telegraf#6666: Fix many plugin errors are logged at debug logging level
  * telegraf#6652: Use nanosecond precision in docker_log input
  * telegraf#6642: Fix interface option with method = native in ping input
  * telegraf#6680: Fix panic in mongodb input if shard connection pool stats are unreadable (telegraf#6680)
  * v1.12.5 [2019-11-12]
  * telegraf#6576: Fix incorrect results in ping input plugin
  * telegraf#6610: Add missing character replacement to sql_instance tag
  * telegraf#6337: Change no metric error message to debug level in cloudwatch input
  * telegraf#6602: Add missing ServerProperties query to sqlserver input docs
  * telegraf#6643: Fix mongodb connections_total_created field loading
  * telegraf#6627: Fix metric creation when node is offline in jenkins input
  * telegraf#6649: Fix docker uptime_ns calculation when container has been restarted
  * telegraf#6647: Fix mysql field type conflict in conversion of gtid_mode to an integer
  * telegraf#5529: Fix mysql field type conflict with ssl_verify_depth and ssl_ctx_verify_depth
  * v1.12.4 [2019-10-23]
  * telegraf#6521: Fix metric generation with ping input native method
  * telegraf#6541: Exclude alias tag if unset from plugin internal stats
  * telegraf#6564: Fix socket_mode option in powerdns_recursor input
  * v1.12.3 [2019-10-07]
  * telegraf#6445: Use batch serialization format in exec output
  * telegraf#6464: Use case insensitive serial numer match in smart input
  * telegraf#6469: Add auth header only when env var is set
  * telegraf#6468: Fix running multiple mysql and sqlserver plugin instances
  * telegraf#6471: Fix database routing on retry with exclude_database_tag
  * telegraf#6488: Fix logging panic in exec input with nagios data format
  * v1.12.2 [2019-09-24]
  * telegraf#6386: Fix detection of layout timestamps in csv and json parser
  * telegraf#6394: Fix parsing of BATTDATE in apcupsd input
  * telegraf#6398: Keep boolean values listed in json_string_fields
  * telegraf#6393: Disable Go plugin support in official builds
  * telegraf#6391: Fix path handling issues in cisco_telemetry_gnmi
  * v1.12.1 [2019-09-10]
  * telegraf#6344: fix depends on glibc_2.14 symbol version
  * telegraf#6329: fix filecount for paths with trailing slash
  * telegraf#6331: convert check state to an integer in icinga2 input
  * telegraf#6354: fix could not mark message delivered error in kafka_consumer
  * telegraf#6362: skip collection stats when disabled in mongodb input
  * telegraf#6366: fix error reading closed response body on redirect in http_response
  * telegraf#6373: fix apcupsd documentation to reflect plugin
  * telegraf#6375: display retry log message only when retry after is received
* Tue Sep 10 2019 Jan Engelhardt <jengelh@inai.de>
- Trim future goals from description, it is not in the scope
  of openSUSE package descriptions.
* Mon Sep  9 2019 Stephan Kulow <coolo@suse.com>
- disable pie on power as it seems to cause problems on go
* Mon Sep  9 2019 Stephan Kulow <coolo@suse.com>
- Update to release 1.12
  Release Notes
  The cluster health related fields in the elasticsearch input have been split
  out from the elasticsearch_indices mesasurement into the new
  elasticsearch_cluster_health_indices measurement as they were originally
  combined by error.
  New Inputs
  apcupsd - Contributed by @jonaz
  docker_log - Contributed by @prashanthjbabu
  fireboard - Contributed by @ronnocol
  logstash - Contributed by @lkmcs @dmitryilyin @arkady-emelyanov
  marklogic - Contributed by @influxdata
  openntpd - Contributed by @aromeyer
  uwsgi - Contributed by @blaggacao
  New Parsers
  form_urlencoded - Contributed by @byonchev
  New Processors
  date - Contributed by @influxdata
  pivot - Contributed by @influxdata
  tag_limit - Contributed by @memory
  unpivot - Contributed by @influxdata
  New Outputs
  exec - Contributed by @Jaeyo
- Update to release 1.11
  Release Notes
  The uptime_format field in the system input has been deprecated, use the
  uptime field instead.
  The cloudwatch input has been updated to use a more efficient API, it now
  requires GetMetricData permissions instead of GetMetricStatistics. The
  units tag is not available from this API and is no longer collected.
  New Inputs
  bind - Contributed by @dswarbrick & @danielllek
  cisco_telemetry_gnmi - Contributed by @sbyx
  cisco_telemetry_mdt - Contributed by @sbyx
  ecs - Contributed by @rbtr
  github - Contributed by @influxdata
  openweathermap - Contributed by @regel
  powerdns_recursor - Contributed by @dupondje
  New Aggregators
  final - Contributed by @oplehto
  New Outputs
  syslog - Contributed by @javicrespo
  health - Contributed by @influxdata
  New Serializers
  wavefront - Contributed by @puckpuck
- Update to release 1.10
  New Inputs
  cloud_pubsub - Contributed by @emilymye
  cloud_pubsub_push - Contributed by @influxdata
  kinesis_consumer - Contributed by @influxdata
  kube_inventory - Contributed by @influxdata
  neptune_apex - Contributed by @MaxRenaud
  nginx_upstream_check - Contributed by @dmitryilyin
  multifile - Contributed by @martin2250
  stackdriver - Contributed by @WuHan0608
  New Outputs
  cloud_pubsub - Contributed by @emilymye
  New Serializers
  nowmetric - Contributed by @JefMuller
  carbon2 - Contributed by @frankreno
- Update to release 1.9
  Release Notes
  The http_listener input plugin has been renamed to influxdb_listener and
  use of the original name is deprecated. The new name better describes the
  intended use of the plugin as a InfluxDB relay. For general purpose
  transfer of metrics in any format via HTTP, it is recommended to use
  http_listener_v2 instead.
  Input plugins are no longer limited from adding metrics when the output is
  writing, and new metrics will move into the metric buffer as needed. This
  will provide more robust degradation and recovery when writing to a slow
  output at high throughput.
  To avoid over consumption when reading from queue consumers: kafka_consumer,
  amqp_consumer, mqtt_consumer, nats_consumer, and nsq_consumer use
  the new option max_undelivered_messages to limit the number of outstanding
  unwritten metrics.
  New Inputs
  http_listener_v2 - Contributed by @jul1u5
  ipvs - Contributed by @amoghe
  jenkins - Contributed by @influxdata & @lpic10
  nginx_plus_api - Contributed by @Bugagazavr
  nginx_vts - Contributed by @monder
  wireless - Contributed by @jamesmaidment
  New Outputs
  stackdriver - Contributed by @jamesmaidment
* Wed Mar 27 2019 Jan Engelhardt <jengelh@inai.de>
- Add systemd-rpm-macros and %%systemd_ordering for %%service_*.
* Wed Mar 27 2019 Stephan Kulow <coolo@suse.com>
- Remove consul/website from the deps - their license is fishy
  and we don't need it to build telegraf
* Thu Nov 15 2018 <nsinger@suse.com>
- Enable PIE for build
- Include systemd service file from upstream
- Drop feature_passive_amqp_exchange.patch
  * Changelog entry tracking dropped patch retroactively added
    by Jeff Kowalczyk <jkowalczyk@suse.com> contemporaneous to
    OBS change devel:languages:go/telegraf r7
- Add 0001-Generic-SQL-output-plugin-for-Telegraf.patch
  * Plugin inserts metric values to databases: mssql, mysql, postgres
  * Changelog entry tracking carried patch retroactively added
    by Jeff Kowalczyk <jkowalczyk@suse.com> contemporaneous to
    OBS change devel:languages:go/telegraf r7
* Thu Nov  1 2018 Tuukka Pasanen <tuukka.pasanen@ilmi.fi>
- Update to release 1.8.3
  - Update deps package
  * v1.8.3 [2018-10-30]
    [#4873]: Add DN attributes as tags in x509_cert input to avoid series overwrite.
    [#4921]: Prevent connection leak by closing unused connections in amqp output.
    [#4904]: Use default partition key when tag does not exist in kinesis output.
    [#4901]: Log the correct error in jti_openconfig.
    [#4937]: Handle panic when ipmi_sensor input gets bad input.
    [#4930]: Don't add unserializable fields to jolokia2 input.
    [#4866]: Fix version check in postgresql_extensible.
  * v1.8.2 [2018-10-17]
  - Bugfixes
    [#4844]: Update write path to match updated InfluxDB v2 API.
    [#4840]: Fix missing timeouts in vsphere input.
    [#4851]: Support uint fields in aerospike input.
    [#4854]: Use container name from list if no name in container stats.
    [#4850]: Prevent panic in filecount input on error in file stat.
    [#4846]: Fix mqtt_consumer connect and reconnect.
    [#4849]: Fix panic in logparser input.
    [#4869]: Lower authorization errors to debug level in mongodb input.
    [#4875]: Return correct response code on ping input.
    [#4874]: Fix segfault in x509_cert input.
  * v1.8.1 [2018-10-03]
  - Bugfixes
    [#4750]: Fix hardware_type may be truncated in sqlserver input.
    [#4723]: Improve performance in basicstats aggregator.
    [#4747]: Add hostname to TLS config for SNI support.
    [#4675]: Don't add tags with empty values to opentsdb output.
    [#4765]: Fix panic during network error in vsphere input.
    [#4766]: Unify http_listener error response with InfluxDB.
    [#4769]: Add UUID to VMs in vSphere input.
    [#4758]: Skip tags with empty values in cloudwatch output.
    [#4783]: Fix missing non-realtime samples in vSphere input.
    [#4799]: Fix case of timezone/grok_timezone options.
  * v1.8 [2018-09-21]
  - New Inputs
    activemq - Contributed by @mlabouardy
    beanstalkd - Contributed by @44px
    filecount - Contributed by @sometimesfood
    file - Contributed by @maxunt
    icinga2 - Contributed by @mlabouardy
    kibana - Contributed by @lpic10
    pgbouncer - Contributed by @nerzhul
    temp - Contributed by @pytimer
    tengine - Contributed by @ertaoxu
    vsphere - Contributed by @prydin
    x509_cert - Contributed by @jtyr
  - New Processors
    enum - Contributed by @KarstenSchnitter
    parser - Contributed by @Ayrdrie & @maxunt
    rename - Contributed by @goldibex
    strings - Contributed by @bsmaldon
  - New Aggregators
    valuecounter - Contributed by @piotr1212
  - New Outputs
    azure_monitor - Contributed by @influxdata
    influxdb_v2 - Contributed by @influxdata
  - New Parsers
    csv - Contributed by @maxunt
    grok - Contributed by @maxunt
    logfmt - Contributed by @Ayrdrie & @maxunt
    wavefront - Contributed by @puckpuck
  - New Serializers
    splunkmetric - Contributed by @ronnocol
  - Features
    [#4236]: Add SSL/TLS support to redis input.
    [#4160]: Add tengine input plugin.
    [#4262]: Add power draw field to nvidia_smi plugin.
    [#4271]: Add support for solr 7 to the solr input.
    [#4281]: Add owner tag on partitions in burrow input.
    [#4259]: Add container status tag to docker input.
    [#3523]: Add valuecounter aggregator plugin.
    [#4307]: Add new measurement with results of pgrep lookup to procstat input.
    [#4311]: Add support for comma in logparser timestamp format.
    [#4292]: Add path tag to tail input plugin.
    [#4322]: Add log message when tail is added or removed from a file.
    [#4267]: Add option to use of counter time in win perf counters.
    [#4343]: Add energy and power field and device id tag to fibaro input.
    [#4347]: Add http path configuration for OpenTSDB output.
    [#4352]: Gather IPMI metrics concurrently.
    [#4362]: Add mongo document and connection metrics.
    [#3772]: Add enum processor plugin.
    [#4386]: Add user tag to procstat input.
    [#4403]: Add support for multivalue metrics to collectd parser.
    [#4418]: Add support for setting kafka client id.
    [#4332]: Add file input plugin and grok parser.
    [#4320]: Improve cloudwatch output performance.
    [#3768]: Add x509_cert input plugin.
    [#4471]: Add IPSIpAddress syntax to ipaddr conversion in snmp plugin.
    [#4363]: Add filecount input plugin.
    [#4485]: Add support for configuring an AWS endpoint_url.
    [#4491]: Send all messages before waiting for results in kafka output.
    [#4492]: Add support for lz4 compression to kafka output.
    [#4450]: Split multiple sensor keys in ipmi input.
    [#4364]: Support StatisticValues in cloudwatch output plugin.
    [#4431]: Add ip restriction for the prometheus_client output.
    [#3918]: Add pgbouncer input plugin.
    [#2689]: Add ActiveMQ input plugin.
    [#4402]: Add wavefront parser plugin.
    [#4528]: Add rename processor plugin.
    [#4537]: Add message 'max_bytes' configuration to kafka input.
    [#4546]: Add gopsutil meminfo fields to mem plugin.
    [#4285]: Document how to parse telegraf logs.
    [#4542]: Use dep v0.5.0.
    [#4433]: Add ability to set measurement from matched text in grok parser.
    [#4565]: Drop message batches in kafka output if too large.
    [#4579]: Add support for static and random routing keys in kafka output.
    [#4539]: Add logfmt parser plugin.
    [#4551]: Add parser processor plugin.
    [#4559]: Add Icinga2 input plugin.
    [#4351]: Add name, time, path and string field options to JSON parser.
    [#4571]: Add forwarded records to sqlserver input.
    [#4585]: Add Kibana input plugin.
    [#4439]: Add csv parser plugin.
    [#4598]: Add read_buffer_size option to statsd input.
    [#4089]: Add azure_monitor output plugin.
    [#4628]: Add queue_durability parameter to amqp_consumer input.
    [#4476]: Add strings processor.
    [#4536]: Add OAuth2 support to HTTP output plugin.
    [#4633]: Add Unix epoch timestamp support for JSON parser.
    [#4657]: Add options for basic auth to haproxy input.
    [#4411]: Add temp input plugin.
    [#4272]: Add Beanstalkd input plugin.
    [#4669]: Add means to specify server password for redis input.
    [#4339]: Add Splunk Metrics serializer.
    [#4141]: Add input plugin for VMware vSphere.
    [#4667]: Align metrics window to interval in cloudwatch input.
    [#4642]: Improve Azure Managed Instance support + more in sqlserver input.
    [#4682]: Allow alternate binaries for iptables input plugin.
    [#4645]: Add influxdb_v2 output plugin.
  - Bugfixes
    [#3438]: Fix divide by zero in logparser input.
    [#4499]: Fix instance and object name in performance counters with backslashes.
    [#4646]: Reset/flush saved contents from bad metric.
    [#4520]: Document all supported cli arguments.
    [#4674]: Log access denied opening a service at debug level in win_services.
    [#4588]: Add support for Kafka 2.0.
    [#4087]: Fix nagios parser does not support ranges in performance data.
    [#4088]: Fix nagios parser does not strip quotes from performance data.
    [#4688]: Fix null value crash in postgresql_extensible input.
    [#4681]: Remove the startup authentication check from the cloudwatch output.
    [#4644]: Support tailing files created after startup in tail input.
    [#4706]: Fix csv format configuration loading.
* Tue Sep 18 2018 Tuukka Pasanen <tuukka.pasanen@ilmi.fi>
- Update to release 1.7.4
  - Update deps package
  * v1.7.4 [2018-08-29]
  - Bugfixes
    [#4534]: Skip unserializable metric in influxDB UDP output.
    [#4554]: Fix powerdns input tests.
    [#4584]: Fix burrow_group offset calculation for burrow input.
    [#4550]: Add result_code value for errors running ping command.
    [#4605]: Remove timeout deadline for udp syslog input.
    [#4601]: Ensure channel closed if an error occurs in cgroup input.
    [#4544]: Fix sending of basic auth credentials in http output.
    [#4526]: Use the correct GOARM value in the armel package.
  * v1.7.3 [2018-08-07]
  - Bugfixes
    [#4434]: Reduce required docker API version.
    [#4498]: Keep leading whitespace for messages in syslog input.
    [#4470]: Skip bad entries on interrupt input.
    [#4501]: Preserve metric type when using filters in output plugins.
    [#3794]: Fix error message if URL is unparseable in influxdb output.
    [#4059]: Use explicit zpool properties to fix parse error on FreeBSD 11.2.
    [#4514]: Lock buffer when adding metrics.
  * v1.7.2 [2018-07-18]
  - Bugfixes
    [#4381]: Use localhost as default server tag in zookeeper input.
    [#4374]: Don't set values when pattern doesn't match in regex processor.
    [#4416]: Fix output format of printer processor.
    [#4422]: Fix metric can have duplicate field.
    [#4389]: Return error if NewRequest fails in http output.
    [#4335]: Reset read deadline for syslog input.
    [#4375]: Exclude cached memory on docker input plugin.
  * v1.7.1 [2018-07-03]
  - Bugfixes
    [#4277]: Treat sigterm as a clean shutdown signal.
    [#4284]: Fix selection of tags under nested objects in the JSON parser.
    [#4135]: Fix postfix input handling multi-level queues.
    [#4334]: Fix syslog timestamp parsing with single digit day of month.
    [#2910]: Handle mysql input variations in the user_statistics collecting.
    [#4293]: Fix minmax and basicstats aggregators to use uint64.
    [#4290]: Document swap input plugin.
    [#4316]: Fix incorrect precision being applied to metric in http_listener.
  * v1.7 [2018-06-12]
  - Release Notes
    The cassandra input plugin has been deprecated in favor of the jolokia2
    input plugin which is much more configurable and more performant.
    There is an example configuration to help you get started.
    For plugins supporting TLS, you can now specify the certificate and keys
    using tls_ca, tls_cert, tls_key. These options behave the same as the,
    now deprecated, ssl forms.
  - New Inputs
    aurora - Contributed by @influxdata
    burrow - Contributed by @arkady-emelyanov
    fibaro - Contributed by @dynek
    jti_openconfig_telemetry - Contributed by @ajhai
    mcrouter - Contributed by @cthayer
    nvidia_smi - Contributed by @jackzampolin
    syslog - Contributed by @influxdata
  - New Processors
    converter - Contributed by @influxdata
    regex - Contributed by @44px
    topk - Contributed by @mirath
  - New Outputs
    http - Contributed by @Dark0096
    application_insights: Contribute by @karolz-ms
  - Features
    [#3964]: Add repl_oplog_window_sec metric to mongodb input.
    [#3819]: Add per-host shard metrics in mongodb input.
    [#3999]: Skip files with leading .. in config directory.
    [#4021]: Add TLS support to socket_writer and socket_listener plugins.
    [#4025]: Add snmp input option to strip non fixed length index suffixes.
    [#4035]: Add server version tag to docker input.
    [#4044]: Add support for LeoFS 1.4 to leofs input.
    [#4068]: Add parameter to force the interval of gather for sysstat.
    [#3877]: Support busybox ping in the ping input.
    [#4077]: Add input plugin for McRouter.
    [#4096]: Add topk processor plugin.
    [#4114]: Add cursor metrics to mongodb input.
    [#3455]: Add tag/integer pair for result to net_response.
    [#4010]: Add application_insights output plugin.
    [#4167]: Added several important elasticsearch cluster health metrics.
    [#4094]: Add batch mode to mqtt output.
    [#4158]: Add aurora input plugin.
    [#3839]: Add regex processor plugin.
    [#4165]: Add support for Graphite 1.1 tags.
    [#4162]: Add timeout option to sensors input.
    [#3489]: Add burrow input plugin.
    [#3969]: Add option to unbound module to use threads as tags.
    [#4183]: Add support for TLS and username/password auth to aerospike input.
    [#4190]: Add special syslog timestamp parser to grok parser that uses current year.
    [#4181]: Add syslog input plugin.
    [#4212]: Print the enabled aggregator and processor plugins on startup.
    [#3994]: Add static routing_key option to amqp output.
    [#3995]: Add passive mode exchange declaration option to amqp consumer input.
    [#4216]: Add counter fields to pf input.
  - Bugfixes
    [#4018]: Write to working file outputs if any files are not writeable.
    [#4036]: Add all win_perf_counters fields for a series in a single metric.
    [#4118]: Report results of dns_query instead of 0ms on timeout.
    [#4155]: Add consul service tags to metric.
    [#2879]: Fix wildcards and multi instance processes in win_perf_counters.
    [#2468]: Fix crash on 32-bit Windows in win_perf_counters.
    [#4198]: Fix win_perf_counters not collecting at every interval.
    [#4227]: Use same flags for all BSD family ping variants.
    [#4266]: Remove tags with empty values from Wavefront output.
  * v1.6.4 [2018-06-05]
  - Bugfixes
    [#4203]: Fix snmp overriding of auto-configured table fields.
    [#4218]: Fix uint support in cloudwatch output.
    [#4188]: Fix documentation of instance_name option in varnish input.
    [#4195]: Revert to previous aerospike library version due to memory leak.
* Sun May 27 2018 tuukka.pasanen@ilmi.fi
- Update to release 1.6.0
  - Update deps package
  * v1.6.3 [2018-05-21]
  - Bugfixes
    [#4127]: Fix intermittent panic in aerospike input.
    [#4130]: Fix connection leak in jolokia2_agent.
    [#4136]: Fix jolokia2 timeout parsing.
    [#4142]: Fix error parsing dropwizard metrics.
    [#4149]: Fix librato output support for uint and bool.
    [#4176]: Fix waitgroup deadlock if url is incorrect in apache input.
  * v1.6.2 [2018-05-08]
  - Bugfixes
    [#4078]: Use same timestamp for fields in system input.
    [#4091]: Fix handling of uint64 in datadog output.
    [#4099]: Ignore UTF8 BOM in JSON parser.
    [#4104]: Fix case for slave metrics in mysql input.
    [#4110]: Fix uint support in cratedb output.
  * v1.6.1 [2018-04-23]
  - Bugfixes
    [#3835]: Report mem input fields as gauges instead counters.
    [#4030]: Fix graphite outputs unsigned integers in wrong format.
    [#4043]: Report available fields if utmp is unreadable.
    [#4039]: Fix potential "no fields" error writing to outputs.
    [#4037]: Fix uptime reporting in system input when ran inside docker.
    [#3750]: Fix mem input "cannot allocate memory" error on FreeBSD based systems.
    [#4056]: Fix duplicate tags when overriding an existing tag.
    [#4062]: Add server argument as first argument in unbound input.
    [#4063]: Fix handling of floats with multiple leading zeroes.
    [#4064]: Return errors in mongodb SSL/TLS configuration.
* Tue Apr 24 2018 mschnitzer@suse.com
- Fix dependency package: The dependency package contained the
  telegraf source code which has overwritten the patched files.
* Wed Apr 18 2018 mschnitzer@suse.com
- Release 1.6.0
  * Release Notes
  - The mysql input plugin has been updated fix a number of type convertion issues. This may cause a field type error when inserting
    into InfluxDB due the change of types.
  - To address this we have introduced a new metric_version option to control enabling the new format. For in depth recommendations on
    upgrading please reference the mysql plugin documentation.
  - It is encouraged to migrate to the new model when possible as the old version is deprecated and will be removed in a future version.
  - The postgresql plugins now defaults to using a persistent connection to the database. In environments where TCP connections are
    terminated the max_lifetime setting should be set less than the collection interval to prevent errors.
  - The sqlserver input plugin has a new query and data model that can be enabled by setting query_version = 2. It is encouraged to
    migrate to the new model when possible as the old version is deprecated and will be removed in a future version.
  - An option has been added to the openldap input plugin that reverses metric name to improve grouping. This change is enabled
    when reverse_metric_names = true is set. It is encouraged to enable this option when possible as the old ordering is deprecated.
  - The new http input configured with data_format = "json" can perform the same task as the, now deprecated, httpjson input.
  * New Inputs
    http - Thanks to @grange74
    ipset - Thanks to @sajoupa
    nats - Thanks to @mjs & @levex
  * New Processors
    override - Thanks to @KarstenSchnitter
  * New Parsers
    dropwizard - Thanks to @atzoum
  * Features
    [#3551]: Add health status mapping from string to int in elasticsearch input.
    [#3580]: Add control over which stats to gather in basicstats aggregator.
    [#3596]: Add messages_delivered_get to rabbitmq input.
    [#3632]: Add wired field to mem input.
    [#3619]: Add support for gathering exchange metrics to the rabbitmq input.
    [#3565]: Add support for additional metrics on Linux in zfs input.
    [#3524]: Add available_entropy field to kernel input plugin.
    [#3643]: Add user privilege level setting to IPMI sensors.
    [#2701]: Use persistent connection to postgresql database.
    [#2846]: Add support for dropwizard input format.
    [#3666]: Add container health metrics to docker input.
    [#3687]: Add support for using globs in devices list of diskio input plugin.
    [#2754]: Allow running as console application on Windows.
    [#3703]: Add listener counts and node running status to rabbitmq input.
    [#3674]: Add NATS Monitoring Input Plugin.
    [#3702]: Add ability to select which queues will be gathered in rabbitmq input.
    [#3726]: Add support for setting bsd source address to the ping input.
    [#3346]: Add Ipset input plugin.
    [#3719]: Add TLS and HTTP basic auth to prometheus_client output.
    [#3618]: Add new sqlserver output data model.
    [#3559]: Add native Go method for finding pids to procstat.
    [#3722]: Add additional metrics and reverse metric names option to openldap.
    [#3769]: Add TLS support to the mesos input plugin.
    [#3546]: Add http input plugin.
    [#3781]: Add keep alive support to the TCP mode of statsd.
    [#3783]: Support deadline in ping plugin.
    [#3765]: Add option to disable labels in prometheus output for string fields.
    [#3808]: Add shard server stats to the mongodb input plugin.
    [#3713]: Add server option to unbound plugin.
    [#3804]: Convert boolean metric values to float in datadog output.
    [#3799]: Add Solr 3 compatibility.
    [#3797]: Add sum stat to basicstats aggregator.
    [#3626]: Add ability to override proxy from environment in http response.
    [#3853]: Add host to ping timeout log message.
    [#3773]: Add override processor.
    [#3814]: Add status_code and result tags and result_type field to http_response input.
    [#3880]: Added config flag to skip collection of network protocol metrics.
    [#3927]: Add TLS support to kapacitor input.
    [#3496]: Add HTTP basic auth support to the http_listener input.
    [#3452]: Tags in output InfluxDB Line Protocol are now sorted.
    [#3631]: InfluxDB Line Protocol parser now accepts DOS line endings.
    [#2496]: An option has been added to skip database creation in the InfluxDB output.
    [#3366]: Add support for connecting to InfluxDB over a unix domain socket.
    [#3946]: Add optional unsigned integer support to the influx data format.
    [#3811]: Add TLS support to zookeeper input.
    [#2737]: Add filters for container state to docker input.
  * Bugfixes
    [#1896]: Fix various mysql data type conversions.
    [#3810]: Fix metric buffer limit in internal plugin after reload.
    [#3801]: Fix panic in http_response on invalid regex.
    [#3973]: Fix socket_listener setting ReadBufferSize on tcp sockets.
    [#1575]: Add tag for target url to phpfpm input.
    [#3868]: Fix cannot unmarshal object error in DC/OS input.
    [#3648]: Fix InfluxDB output not able to reconnect when server address changes.
    [#3957]: Fix parsing of dos line endings in the smart input.
    [#3754]: Fix precision truncation when no timestamp included.
    [#3655]: Fix SNMPv3 connection with Cisco ASA 5515 in snmp input.
    [#3981]: Export all vars defined in /etc/default/telegraf.
    [#4004]: Allow grok pattern to contain newlines.
* Fri Mar 23 2018 mschnitzer@suse.com
- Release 1.5.3
  * Bugfixes
    [#3729]: Set path to / if HOST_MOUNT_PREFIX matches full path.
    [#3739]: Remove userinfo from url tag in prometheus input.
    [#3778]: Fix ping plugin not reporting zero durations.
    [#3807]: Fix memory leak in postgresql_extensible.
    [#3697]: Disable keepalive in mqtt output to prevent deadlock.
    [#3786]: Fix collation difference in sqlserver input.
    [#3871]: Fix uptime metric in passenger input plugin.
    [#3851]: Add output of stderr in case of error to exec log message.
* Mon Feb 12 2018 mschnitzer@suse.com
- Add feature_passive_amqp_exchange.patch:
  * This patch allows to enable the exchange passive mode for the
    AMQP consumer plugin. This is required for RabbitMQ servers
  that rely on that (like the openSUSE ones)
  * Upstream pull request is not possible because it requires you
    to sign a CLA, but it's requested here:
  https://github.com/influxdata/telegraf/issues/3785
* Thu Feb  8 2018 mschnitzer@suse.com
- Release 1.5.2
  * Bugfixes
    [#3684]: Ignore empty lines in Graphite plaintext.
    [#3604]: Fix index out of bounds error in solr input plugin.
    [#3680]: Reconnect before sending graphite metrics if disconnected.
    [#3693]: Align aggregator period with internal ticker to avoid skipping metrics.
    [#3629]: Fix a potential deadlock when using aggregators.
    [#3697]: Limit wait time for writes in mqtt output.
    [#3698]: Revert change in graphite output where dot in field key was replaced by underscore.
    [#3710]: Add timeout to wavefront output write.
    [#3725]: Exclude master_replid fields from redis input.
